module Text.LaTeX.Entities where

import Data.Char (chr)
import qualified Data.Map as Map

data Mapping = Mapping (Maybe Char) LaTeX
data LaTeX = LaTeX String | LaTeXMath String

-- |Return the (non-math) LaTeX sequence for some known unicode
-- characters.  At this time the standard ASCII characters are not
-- covered.
unicodeToLaTeX :: Char -> Maybe String
unicodeToLaTeX c = Map.lookup c unicodeLaTeXMap

unicodeLaTeXMap :: Map.Map Char String
unicodeLaTeXMap =
    Map.fromList (concatMap doMapping (latexEntities ++ latexEntities2))
    where
      doltx :: LaTeX -> Char -> [(Char, String)]
      doltx (LaTeX s) uc = [(uc, s)]
      doltx (LaTeXMath s) uc = [(uc, "$" ++ s ++ "$")]
      doMapping :: Mapping -> [(Char, String)]
      doMapping (Mapping ucs ltx) = maybe [] (doltx ltx) ucs

-- This list is split into two pieces to work around a GHC 6.10.4 bug:
--   http://hackage.haskell.org/trac/ghc/ticket/3488
latexEntities = [
  Mapping (Just (chr 8195)) (LaTeX "\\hspace{1em}"),
  Mapping (Just (chr 8195)) (LaTeXMath "\\quad"),
  Mapping (Just (chr 8194)) (LaTeX "\\hspace{0.5em}"),
  Mapping (Just (chr 8194)) (LaTeXMath "\\;"),
  Mapping (Just (chr 8196)) (LaTeX "\\hspace{0.33em}"),
  Mapping (Just (chr 8196)) (LaTeXMath "\\:"),
  Mapping (Just (chr 8197)) (LaTeX "\\hspace{0.25em}"),
  Mapping (Just (chr 8199)) (LaTeX "\\hphantom{0}"),
  Mapping (Just (chr 8200)) (LaTeX "\\hphantom{,}"),
  Mapping (Just (chr 8201)) (LaTeX "\\hspace{0.167em}"),
  Mapping (Just (chr 8201)) (LaTeXMath "\\,"),
  Mapping (Just (chr 8202)) (LaTeX "\\hspace{1pt}"),
  Mapping (Just (chr 8212)) (LaTeX "---"),
  Mapping (Just (chr 8212)) (LaTeX "\\textemdash"),
  Mapping (Just (chr 8211)) (LaTeX "--"),
  Mapping (Just (chr 8211)) (LaTeX "\\textendash"),
  Mapping (Just (chr 8208)) (LaTeX "-"),
  Mapping (Just (chr 9251)) (LaTeX "\\textvisiblespace"),
  Mapping (Just (chr 8230)) (LaTeX "\\ldots"),
  Mapping (Just (chr 8230)) (LaTeX "\\textellipsis"),
  Mapping (Just (chr 8229)) (LaTeX "\\nldr"),
  Mapping (Just (chr 8531)) (LaTeXMath "\\sfrac{1}{3}"),
  Mapping (Just (chr 8531)) (LaTeXMath "\\frac{1}{3}"),
  Mapping (Just (chr 8532)) (LaTeXMath "\\sfrac{2}{3}"),
  Mapping (Just (chr 8532)) (LaTeXMath "\\frac{2}{3}"),
  Mapping (Just (chr 8533)) (LaTeXMath "\\sfrac{1}{5}"),
  Mapping (Just (chr 8533)) (LaTeXMath "\\frac{1}{5}"),
  Mapping (Just (chr 8534)) (LaTeXMath "\\sfrac{2}{5}"),
  Mapping (Just (chr 8534)) (LaTeXMath "\\frac{2}{5}"),
  Mapping (Just (chr 8535)) (LaTeXMath "\\sfrac{3}{5}"),
  Mapping (Just (chr 8535)) (LaTeXMath "\\frac{3}{5}"),
  Mapping (Just (chr 8536)) (LaTeXMath "\\sfrac{4}{5}"),
  Mapping (Just (chr 8536)) (LaTeXMath "\\frac{4}{5}"),
  Mapping (Just (chr 8537)) (LaTeXMath "\\sfrac{1}{6}"),
  Mapping (Just (chr 8537)) (LaTeXMath "\\frac{1}{6}"),
  Mapping (Just (chr 8538)) (LaTeXMath "\\sfrac{5}{6}"),
  Mapping (Just (chr 8538)) (LaTeXMath "\\frac{5}{6}"),
  Mapping (Just (chr 8453)) (LaTeXMath "{^c\\!/\\!_o}"),
  Mapping (Just (chr 9608)) (LaTeX "\\block"),
  Mapping (Just (chr 9600)) (LaTeX "\\uhblk"),
  Mapping (Just (chr 9604)) (LaTeX "\\lhblk"),
  Mapping (Just (chr 9617)) (LaTeX "\\textcolor[gray]{.75}{\\block}"),
  Mapping (Just (chr 9618)) (LaTeX "\\textcolor[gray]{.5}{\\block}"),
  Mapping (Just (chr 9619)) (LaTeX "\\textcolor[gray]{.25}{\\block}"),
  Mapping (Just (chr 9646)) (LaTeX "\\marker"),
  Mapping (Just (chr 9675)) (LaTeXMath "\\circ"),
  Mapping (Just (chr 9633)) (LaTeXMath "\\square"),
  Mapping (Just (chr 9645)) (LaTeX "\\fbox{~~}"),
  Mapping (Just (chr 9653)) (LaTeXMath "\\vartriangle"),
  Mapping (Just (chr 9653)) (LaTeXMath "\\triangle"),
  Mapping (Just (chr 9663)) (LaTeXMath "\\triangledown"),
  Mapping (Just (chr 9734)) (LaTeX "\\ding{73}"),
  Mapping (Just (chr 8226)) (LaTeX "\\textbullet"),
  Mapping (Just (chr 8226)) (LaTeXMath "\\bullet"),
  Mapping (Just (chr 9642)) (LaTeXMath "\\blacksquare"),
  Mapping (Just (chr 9652)) (LaTeXMath "\\blacktriangle"),
  Mapping (Just (chr 9662)) (LaTeXMath "\\blacktriangledown"),
  Mapping (Just (chr 9666)) (LaTeXMath "\\blacktriangleleft"),
  Mapping (Just (chr 9656)) (LaTeXMath "\\blacktriangleright"),
  Mapping (Just (chr 9827)) (LaTeX "\\ding{168}"),
  Mapping (Just (chr 9827)) (LaTeXMath "\\clubsuit"),
  Mapping (Just (chr 9830)) (LaTeX "\\ding{169}"),
  Mapping (Just (chr 9830)) (LaTeXMath "\\diamondsuit"),
  Mapping (Just (chr 9829)) (LaTeX "\\ding{170}"),
  Mapping (Just (chr 9829)) (LaTeXMath "\\heartsuit"),
  Mapping (Just (chr 9824)) (LaTeX "\\ding{171}"),
  Mapping (Just (chr 9824)) (LaTeXMath "\\spadesuit"),
  Mapping (Just (chr 10016)) (LaTeX "\\maltese"),
  Mapping (Just (chr 10016)) (LaTeX "\\ding{64}"),
  Mapping (Just (chr 8224)) (LaTeX "\\dag"),
  Mapping (Just (chr 8224)) (LaTeX "\\textdagger"),
  Mapping (Just (chr 8224)) (LaTeXMath "\\dagger"),
  Mapping (Just (chr 8225)) (LaTeX "\\ddag"),
  Mapping (Just (chr 8225)) (LaTeX "\\textdaggerdbl"),
  Mapping (Just (chr 8225)) (LaTeXMath "\\ddagger"),
  Mapping (Just (chr 10003)) (LaTeX "\\checkmark"),
  Mapping (Just (chr 10003)) (LaTeX "\\ding{51}"),
  Mapping (Just (chr 10007)) (LaTeX "\\ding{55}"),
  Mapping (Just (chr 9839)) (LaTeXMath "\\sharp"),
  Mapping (Just (chr 9837)) (LaTeXMath "\\flat"),
  Mapping (Just (chr 9794)) (LaTeX "\\male"),
  Mapping (Just (chr 9792)) (LaTeX "\\female"),
  Mapping (Just (chr 9742)) (LaTeX "\\phone"),
  Mapping (Just (chr 9742)) (LaTeX "\\ding{37}"),
  Mapping (Just (chr 8981)) (LaTeX "\\recorder"),
  Mapping (Just (chr 8471)) (LaTeX "\\textcircledP"),
  Mapping (Just (chr 8471)) (LaTeX "\\textcircled{P}"),
  Mapping (Just (chr 8471)) (LaTeX "\\textcircled{\\scshape p}"),
  Mapping (Just (chr 8257)) (LaTeXMath "\\mathchar\"1356"),
  Mapping (Just (chr 8218)) (LaTeX ","),
  Mapping (Just (chr 8218)) (LaTeX "\\quotesinglbase"),
  Mapping (Just (chr 8222)) (LaTeX ",,"),
  Mapping (Just (chr 8222)) (LaTeX "\\quotedblbase"),
  Mapping (Just (chr 64256)) (LaTeX "ff"),
  Mapping (Just (chr 64257)) (LaTeX "fi"),
  Mapping (Just (chr 58290)) (LaTeX "fj"),
  Mapping (Just (chr 64259)) (LaTeX "ffi"),
  Mapping (Just (chr 64260)) (LaTeX "ffl"),
  Mapping (Just (chr 64258)) (LaTeX "fl"),
  Mapping (Just (chr 8230)) (LaTeX "\\mldr"),
  Mapping (Just (chr 8223)) (LaTeX "``"),
  Mapping (Just (chr 8223)) (LaTeX "\\textquotedblleft"),
  Mapping (Just (chr 8219)) (LaTeX "`"),
  Mapping (Just (chr 8942)) (LaTeXMath "\\vdots"),
  Mapping (Just (chr 8259)) (LaTeX "\\hybull"),
  Mapping (Just (chr 9674)) (LaTeXMath "\\lozenge"),
  Mapping (Just (chr 59403)) (LaTeXMath "\\blacklozenge"),
  Mapping (Just (chr 9667)) (LaTeXMath "\\triangleleft"),
  Mapping (Just (chr 9657)) (LaTeXMath "\\triangleright"),
  Mapping (Just (chr 9733)) (LaTeXMath "\\bigstar"),
  Mapping (Just (chr 9838)) (LaTeXMath "\\natural"),
  Mapping (Just (chr 8478)) (LaTeX "\\textrecipe"),
  Mapping (Just (chr 10038)) (LaTeX "\\ding{86}"),
  Mapping (Just (chr 8982)) (LaTeXMath "\\mathchar\"2208"),
  Mapping (Just (chr 8973)) (LaTeX "\\dlcrop"),
  Mapping (Just (chr 8972)) (LaTeX "\\drcrop"),
  Mapping (Just (chr 8975)) (LaTeX "\\ulcrop"),
  Mapping (Just (chr 8974)) (LaTeX "\\urcrop"),
  Mapping (Just (chr 189)) (LaTeXMath "\\sfrac{1}{2}"),
  Mapping (Just (chr 189)) (LaTeXMath "\\frac{1}{2}"),
  Mapping (Just (chr 188)) (LaTeXMath "\\sfrac{1}{4}"),
  Mapping (Just (chr 188)) (LaTeXMath "\\frac{1}{4}"),
  Mapping (Just (chr 190)) (LaTeXMath "\\sfrac{3}{4}"),
  Mapping (Just (chr 190)) (LaTeXMath "\\frac{3}{4}"),
  Mapping (Just (chr 8539)) (LaTeXMath "\\sfrac{1}{8}"),
  Mapping (Just (chr 8539)) (LaTeXMath "\\frac{1}{8}"),
  Mapping (Just (chr 8540)) (LaTeXMath "\\sfrac{3}{8}"),
  Mapping (Just (chr 8540)) (LaTeXMath "\\frac{3}{8}"),
  Mapping (Just (chr 8541)) (LaTeXMath "\\sfrac{5}{8}"),
  Mapping (Just (chr 8541)) (LaTeXMath "\\frac{5}{8}"),
  Mapping (Just (chr 8542)) (LaTeXMath "\\sfrac{7}{8}"),
  Mapping (Just (chr 8542)) (LaTeXMath "\\frac{7}{8}"),
  Mapping (Just (chr 185)) (LaTeXMath "^1"),
  Mapping (Just (chr 178)) (LaTeXMath "^2"),
  Mapping (Just (chr 179)) (LaTeXMath "^3"),
  Mapping (Just (chr 43)) (LaTeXMath "+"),
  Mapping (Just (chr 177)) (LaTeX "\\textpm"),
  Mapping (Just (chr 177)) (LaTeXMath "\\pm"),
  Mapping (Just (chr 60)) (LaTeX "\\textless"),
  Mapping (Just (chr 60)) (LaTeXMath "&lt;"),
  Mapping (Just (chr 61)) (LaTeXMath "="),
  Mapping (Just (chr 62)) (LaTeX "\\textgreater"),
  Mapping (Just (chr 62)) (LaTeXMath "&gt;"),
  Mapping (Just (chr 247)) (LaTeX "\\textdiv"),
  Mapping (Just (chr 247)) (LaTeXMath "\\div"),
  Mapping (Just (chr 215)) (LaTeX "\\texttimes"),
  Mapping (Just (chr 215)) (LaTeXMath "\\times"),
  Mapping (Just (chr 164)) (LaTeX "\\textcurrency"),
  Mapping (Just (chr 164)) (LaTeX "\\currency"),
  Mapping (Just (chr 163)) (LaTeX "\\pounds"),
  Mapping (Just (chr 163)) (LaTeX "\\textsterling"),
  Mapping (Just (chr 163)) (LaTeXMath "\\mathsterling"),
  Mapping (Just (chr 36)) (LaTeX "\\$"),
  Mapping (Just (chr 36)) (LaTeX "\\textdollar"),
  Mapping (Just (chr 162)) (LaTeX "\\textcent"),
  Mapping (Just (chr 162)) (LaTeX "\\cent"),
  Mapping (Just (chr 165)) (LaTeX "\\textyen"),
  Mapping (Just (chr 165)) (LaTeXMath "\\yen"),
  Mapping (Just (chr 35)) (LaTeX "\\#"),
  Mapping (Just (chr 37)) (LaTeX "\\%"),
  Mapping (Just (chr 38)) (LaTeX "\\&amp;"),
  Mapping (Just (chr 42)) (LaTeXMath "\\ast"),
  Mapping (Just (chr 64)) (LaTeX "@"),
  Mapping (Just (chr 91)) (LaTeX "["),
  Mapping (Just (chr 92)) (LaTeX "\\textbackslash"),
  Mapping (Just (chr 92)) (LaTeXMath "\\backslash"),
  Mapping (Just (chr 93)) (LaTeX "]"),
  Mapping (Just (chr 123)) (LaTeX "\\{"),
  Mapping (Just (chr 123)) (LaTeX "\\textbraceleft"),
  Mapping (Just (chr 123)) (LaTeXMath "\\lbrace"),
  Mapping (Just (chr 8213)) (LaTeX "---"),
  Mapping (Just (chr 8213)) (LaTeX "\\rule{1em}{1pt}"),
  Mapping (Just (chr 124)) (LaTeX "\\textbar"),
  Mapping (Just (chr 124)) (LaTeXMath "\\vert"),
  Mapping (Just (chr 124)) (LaTeXMath "|"),
  Mapping (Just (chr 125)) (LaTeX "\\}"),
  Mapping (Just (chr 125)) (LaTeX "\\rbrace"),
  Mapping (Just (chr 181)) (LaTeX "\\textmu"),
  Mapping (Just (chr 181)) (LaTeXMath "\\mathrm{\\mu}"),
  Mapping (Just (chr 8486)) (LaTeX "\\textohm"),
  Mapping (Just (chr 8486)) (LaTeXMath "\\Omega"),
  Mapping (Just (chr 176)) (LaTeX "\\textdegree"),
  Mapping (Just (chr 176)) (LaTeX "\\textdegree"),
  Mapping (Just (chr 176)) (LaTeXMath "^\\circ"),
  Mapping (Just (chr 186)) (LaTeX "\\textordmasculine"),
  Mapping (Just (chr 186)) (LaTeX "\\textordmasculine"),
  Mapping (Just (chr 170)) (LaTeX "\\textordfeminine"),
  Mapping (Just (chr 170)) (LaTeX "\\textordfeminine"),
  Mapping (Just (chr 167)) (LaTeX "\\S"),
  Mapping (Just (chr 167)) (LaTeX "\\textsection"),
  Mapping (Just (chr 182)) (LaTeX "\\P"),
  Mapping (Just (chr 182)) (LaTeX "\\textparagraph"),
  Mapping (Just (chr 182)) (LaTeX "\\textpilcrow"),
  Mapping (Just (chr 183)) (LaTeX "\\textperiodcentered"),
  Mapping (Just (chr 183)) (LaTeXMath "\\cdot"),
  Mapping (Just (chr 183)) (LaTeXMath "\\cdotp"),
  Mapping (Just (chr 183)) (LaTeXMath "\\centerdot"),
  Mapping (Just (chr 8592)) (LaTeX "\\textleftarrow"),
  Mapping (Just (chr 8592)) (LaTeXMath "\\leftarrow"),
  Mapping (Just (chr 8594)) (LaTeX "\\textrightarrow"),
  Mapping (Just (chr 8594)) (LaTeXMath "\\rightarrow"),
  Mapping (Just (chr 8593)) (LaTeX "\\textuparrow"),
  Mapping (Just (chr 8593)) (LaTeXMath "\\uparrow"),
  Mapping (Just (chr 8595)) (LaTeX "\\textdownarrow"),
  Mapping (Just (chr 8595)) (LaTeXMath "\\downarrow"),
  Mapping (Just (chr 169)) (LaTeX "\\copyright"),
  Mapping (Just (chr 169)) (LaTeX "\\textcopyright"),
  Mapping (Just (chr 174)) (LaTeX "\\textregistered"),
  Mapping (Just (chr 174)) (LaTeXMath "\\circledR"),
  Mapping (Just (chr 8482)) (LaTeX "\\texttrademark"),
  Mapping (Just (chr 166)) (LaTeX "\\textbrokenbar"),
  Mapping (Just (chr 166)) (LaTeX "\\brokenvert"),
  Mapping (Just (chr 172)) (LaTeX "\\textlnot"),
  Mapping (Just (chr 172)) (LaTeXMath "\\lnot"),
  Mapping (Just (chr 9834)) (LaTeX "\\textmusicalnote"),
  Mapping (Just (chr 9834)) (LaTeX "\\eighthnote"),
  Mapping (Just (chr 33)) (LaTeX "!"),
  Mapping (Just (chr 161)) (LaTeX "!`"),
  Mapping (Just (chr 161)) (LaTeX "\\textexclamdown"),
  Mapping (Just (chr 34)) (LaTeX "\""),
  Mapping (Just (chr 34)) (LaTeX "\\textquotedbl"),
  Mapping (Just (chr 39)) (LaTeX "'"),
  Mapping (Just (chr 39)) (LaTeX "\\textquotesingle"),
  Mapping (Just (chr 40)) (LaTeX "("),
  Mapping (Just (chr 41)) (LaTeX ")"),
  Mapping (Just (chr 44)) (LaTeX ","),
  Mapping (Just (chr 95)) (LaTeX "\\underline{\\hspace{1ex}}"),
  Mapping (Just (chr 95)) (LaTeX "\\_"),
  Mapping (Just (chr 95)) (LaTeX "\\textunderscore"),
  Mapping (Just (chr 45)) (LaTeX "-"),
  Mapping (Just (chr 46)) (LaTeX "."),
  Mapping (Just (chr 46)) (LaTeX "\\@."),
  Mapping (Just (chr 46)) (LaTeXMath "\\ldotp"),
  Mapping (Just (chr 47)) (LaTeX "/"),
  Mapping (Just (chr 58)) (LaTeX ":"),
  Mapping (Just (chr 58)) (LaTeXMath "\\colon"),
  Mapping (Just (chr 59)) (LaTeX ";"),
  Mapping (Just (chr 63)) (LaTeX "?"),
  Mapping (Just (chr 191)) (LaTeX "?`"),
  Mapping (Just (chr 191)) (LaTeX "\\textquestiondown"),
  Mapping (Just (chr 171)) (LaTeX "\\guillemotleft"),
  Mapping (Just (chr 187)) (LaTeX "\\guillemotright"),
  Mapping (Just (chr 8216)) (LaTeX "`"),
  Mapping (Just (chr 8216)) (LaTeX "\\textquoteleft"),
  Mapping (Just (chr 8217)) (LaTeX "'"),
  Mapping (Just (chr 8217)) (LaTeX "\\textquoteright"),
  Mapping (Just (chr 8220)) (LaTeX "``"),
  Mapping (Just (chr 8220)) (LaTeX "\\textquotedblleft"),
  Mapping (Just (chr 8221)) (LaTeX "''"),
  Mapping (Just (chr 8221)) (LaTeX "\\textquotedblright"),
  Mapping (Just (chr 160)) (LaTeX "~"),
  Mapping (Just (chr 173)) (LaTeX "\\-"),
  Mapping (Just (chr 9472)) (LaTeX "\\boxh"),
  Mapping (Just (chr 9474)) (LaTeX "\\boxv"),
  Mapping (Just (chr 9492)) (LaTeX "\\boxur"),
  Mapping (Just (chr 9496)) (LaTeX "\\boxul"),
  Mapping (Just (chr 9488)) (LaTeX "\\boxdl"),
  Mapping (Just (chr 9484)) (LaTeX "\\boxdr"),
  Mapping (Just (chr 9500)) (LaTeX "\\boxvr"),
  Mapping (Just (chr 9524)) (LaTeX "\\boxhu"),
  Mapping (Just (chr 9508)) (LaTeX "\\boxvl"),
  Mapping (Just (chr 9516)) (LaTeX "\\boxhd"),
  Mapping (Just (chr 9532)) (LaTeX "\\boxvh"),
  Mapping (Just (chr 9566)) (LaTeX "\\boxvR"),
  Mapping (Just (chr 9576)) (LaTeX "\\boxhU"),
  Mapping (Just (chr 9569)) (LaTeX "\\boxvL"),
  Mapping (Just (chr 9573)) (LaTeX "\\boxhD"),
  Mapping (Just (chr 9578)) (LaTeX "\\boxvH"),
  Mapping (Just (chr 9552)) (LaTeX "\\boxH"),
  Mapping (Just (chr 9553)) (LaTeX "\\boxV"),
  Mapping (Just (chr 9562)) (LaTeX "\\boxUR"),
  Mapping (Just (chr 9565)) (LaTeX "\\boxUL"),
  Mapping (Just (chr 9559)) (LaTeX "\\boxDL"),
  Mapping (Just (chr 9556)) (LaTeX "\\boxDR"),
  Mapping (Just (chr 9568)) (LaTeX "\\boxVR"),
  Mapping (Just (chr 9577)) (LaTeX "\\boxHU"),
  Mapping (Just (chr 9571)) (LaTeX "\\boxVL"),
  Mapping (Just (chr 9574)) (LaTeX "\\boxHD"),
  Mapping (Just (chr 9580)) (LaTeX "\\boxVH"),
  Mapping (Just (chr 9567)) (LaTeX "\\boxVr"),
  Mapping (Just (chr 9575)) (LaTeX "\\boxHu"),
  Mapping (Just (chr 9570)) (LaTeX "\\boxVl"),
  Mapping (Just (chr 9572)) (LaTeX "\\boxHd"),
  Mapping (Just (chr 9579)) (LaTeX "\\boxVh"),
  Mapping (Just (chr 9560)) (LaTeX "\\boxuR"),
  Mapping (Just (chr 9564)) (LaTeX "\\boxUl"),
  Mapping (Just (chr 9557)) (LaTeX "\\boxdL"),
  Mapping (Just (chr 9555)) (LaTeX "\\boxDr"),
  Mapping (Just (chr 9561)) (LaTeX "\\boxUr"),
  Mapping (Just (chr 9563)) (LaTeX "\\boxuL"),
  Mapping (Just (chr 9558)) (LaTeX "\\boxDl"),
  Mapping (Just (chr 9554)) (LaTeX "\\boxdR"),
  Mapping (Just (chr 8501)) (LaTeXMath "\\aleph"),
  Mapping (Just (chr 8743)) (LaTeXMath "\\wedge"),
  Mapping (Just (chr 8743)) (LaTeXMath "\\land"),
  Mapping (Just (chr 8735)) (LaTeXMath "\\sqangle"),
  Mapping (Just (chr 8738)) (LaTeXMath "\\sphericalangle"),
  Mapping (Just (chr 8776)) (LaTeXMath "\\approx"),
  Mapping (Just (chr 8757)) (LaTeXMath "\\because"),
  Mapping (Just (chr 8869)) (LaTeXMath "\\bot"),
  Mapping (Just (chr 8745)) (LaTeXMath "\\cap"),
  Mapping (Just (chr 8773)) (LaTeXMath "\\cong"),
  Mapping (Just (chr 8750)) (LaTeXMath "\\oint"),
  Mapping (Just (chr 8746)) (LaTeXMath "\\cup"),
  Mapping (Just (chr 8801)) (LaTeXMath "\\equiv"),
  Mapping (Just (chr 8707)) (LaTeXMath "\\exists"),
  Mapping (Just (chr 8704)) (LaTeXMath "\\forall"),
  Mapping (Just (chr 402)) (LaTeXMath "f"),
  Mapping (Just (chr 8805)) (LaTeXMath "\\geq"),
  Mapping (Just (chr 8805)) (LaTeXMath "\\ge"),
  Mapping (Just (chr 8660)) (LaTeXMath "\\iff"),
  Mapping (Just (chr 8734)) (LaTeXMath "\\infty"),
  Mapping (Just (chr 8747)) (LaTeXMath "\\int"),
  Mapping (Just (chr 8712)) (LaTeXMath "\\in"),
  Mapping (Just (chr 12296)) (LaTeX "\\textlangle"),
  Mapping (Just (chr 12296)) (LaTeXMath "\\langle"),
  Mapping (Just (chr 8656)) (LaTeXMath "\\Leftarrow"),
  Mapping (Just (chr 8804)) (LaTeXMath "\\leq"),
  Mapping (Just (chr 8804)) (LaTeXMath "\\le"),
  Mapping (Just (chr 8722)) (LaTeX "\\textminus"),
  Mapping (Just (chr 8722)) (LaTeXMath "-"),
  Mapping (Just (chr 8723)) (LaTeXMath "\\mp"),
  Mapping (Just (chr 8711)) (LaTeXMath "\\nabla"),
  Mapping (Just (chr 8800)) (LaTeXMath "\\not="),
  Mapping (Just (chr 8800)) (LaTeXMath "\\neq"),
  Mapping (Just (chr 8800)) (LaTeXMath "\\ne"),
  Mapping (Just (chr 8715)) (LaTeXMath "\\ni"),
  Mapping (Just (chr 8715)) (LaTeXMath "\\owns"),
  Mapping (Just (chr 8744)) (LaTeXMath "\\vee"),
  Mapping (Just (chr 8744)) (LaTeXMath "\\lor"),
  Mapping (Just (chr 8741)) (LaTeXMath "\\parallel"),
  Mapping (Just (chr 8706)) (LaTeXMath "\\partial"),
  Mapping (Just (chr 8240)) (LaTeX "\\textperthousand"),
  Mapping (Just (chr 8240)) (LaTeX "\\permil"),
  Mapping (Just (chr 8869)) (LaTeXMath "\\perp"),
  Mapping (Just (chr 8242)) (LaTeXMath "^\\prime"),
  Mapping (Just (chr 8243)) (LaTeXMath "{''}"),
  Mapping (Just (chr 8733)) (LaTeXMath "\\propto"),
  Mapping (Just (chr 8730)) (LaTeX "\\textsurd"),
  Mapping (Just (chr 8730)) (LaTeXMath "\\surd"),
  Mapping (Just (chr 12297)) (LaTeX "\\textrangle"),
  Mapping (Just (chr 12297)) (LaTeXMath "\\rangle"),
  Mapping (Just (chr 8658)) (LaTeXMath "\\Rightarrow"),
  Mapping (Just (chr 8764)) (LaTeXMath "\\sim"),
  Mapping (Just (chr 8771)) (LaTeXMath "\\simeq"),
  Mapping (Just (chr 9632)) (LaTeXMath "\\square"),
  Mapping (Just (chr 8834)) (LaTeXMath "\\subset"),
  Mapping (Just (chr 8838)) (LaTeXMath "\\subseteq"),
  Mapping (Just (chr 8835)) (LaTeXMath "\\supset"),
  Mapping (Just (chr 8839)) (LaTeXMath "\\supseteq"),
  Mapping (Just (chr 8756)) (LaTeXMath "\\therefore"),
  Mapping (Just (chr 8214)) (LaTeX "\\textbardbl"),
  Mapping (Just (chr 8214)) (LaTeXMath "\\Vert"),
  Mapping (Just (chr 8214)) (LaTeXMath "\\|"),
  Mapping (Just (chr 8491)) (LaTeX "\\AA"),
  Mapping (Just (chr 8492)) (LaTeXMath "B"),
  Mapping (Just (chr 8492)) (LaTeXMath "\\mathcal{B}"),
  Mapping (Just (chr 8728)) (LaTeXMath "\\circ"),
  Mapping (Just (chr 168)) (LaTeXMath "\\ddot{}"),
  Mapping (Just (chr 8412)) (LaTeXMath "\\ddot{}\\kern4.5pt\\ddot{ }"),
  Mapping (Just (chr 8459)) (LaTeXMath "H"),
  Mapping (Just (chr 8459)) (LaTeXMath "\\mathcal{H}"),
  Mapping (Just (chr 8466)) (LaTeXMath "L"),
  Mapping (Just (chr 8466)) (LaTeXMath "\\mathcal{L}"),
  Mapping (Just (chr 8727)) (LaTeXMath "_\\ast"),
  Mapping (Just (chr 8713)) (LaTeXMath "\\not\\in"),
  Mapping (Just (chr 8500)) (LaTeXMath "\\mathit{o}"),
  Mapping (Just (chr 8499)) (LaTeXMath "M"),
  Mapping (Just (chr 8499)) (LaTeXMath "\\mathcal{M}"),
  Mapping (Just (chr 8411)) (LaTeXMath "\\ddot{}\\kern 3pt\\dot{ }"),
  Mapping (Just (chr 8244)) (LaTeXMath "{'''}"),
  Mapping (Just (chr 8793)) (LaTeXMath "\\stackrel{\\wedge}{=}"),
  Mapping (Just (chr 8793)) (LaTeXMath "\\wedgeq"),
  Mapping (Just (chr 945)) (LaTeXMath "\\alpha"),
  Mapping (Just (chr 946)) (LaTeXMath "\\beta"),
  Mapping (Just (chr 947)) (LaTeXMath "\\gamma"),
  Mapping (Just (chr 915)) (LaTeXMath "\\Gamma"),
  Mapping (Just (chr 988)) (LaTeXMath "\\digamma"),
  Mapping (Just (chr 948)) (LaTeXMath "\\delta"),
  Mapping (Just (chr 916)) (LaTeXMath "\\Delta"),
  Mapping (Just (chr 949)) (LaTeXMath "\\epsilon"),
  Mapping Nothing (LaTeXMath "\\varepsilon"),
  Mapping (Just (chr 8714)) (LaTeXMath "\\epsilon"),
  Mapping (Just (chr 950)) (LaTeXMath "\\zeta"),
  Mapping (Just (chr 951)) (LaTeXMath "\\eta"),
  Mapping (Just (chr 952)) (LaTeXMath "\\theta"),
  Mapping (Just (chr 920)) (LaTeXMath "\\Theta"),
  Mapping (Just (chr 977)) (LaTeXMath "\\vartheta"),
  Mapping (Just (chr 953)) (LaTeXMath "\\iota"),
  Mapping (Just (chr 954)) (LaTeXMath "\\kappa"),
  Mapping (Just (chr 1008)) (LaTeXMath "\\varkappa"),
  Mapping (Just (chr 955)) (LaTeXMath "\\lambda"),
  Mapping (Just (chr 923)) (LaTeXMath "\\Lambda"),
  Mapping (Just (chr 956)) (LaTeXMath "\\mu"),
  Mapping (Just (chr 957)) (LaTeXMath "\\nu"),
  Mapping (Just (chr 958)) (LaTeXMath "\\xi"),
  Mapping (Just (chr 926)) (LaTeXMath "\\Xi"),
  Mapping (Just (chr 960)) (LaTeXMath "\\pi"),
  Mapping (Just (chr 982)) (LaTeXMath "\\varpi"),
  Mapping (Just (chr 928)) (LaTeXMath "\\Pi"),
  Mapping (Just (chr 961)) (LaTeXMath "\\rho"),
  Mapping (Just (chr 1009)) (LaTeXMath "\\varrho"),
  Mapping (Just (chr 963)) (LaTeXMath "\\sigma"),
  Mapping (Just (chr 931)) (LaTeXMath "\\Sigma"),
  Mapping (Just (chr 962)) (LaTeXMath "\\varsigma"),
  Mapping (Just (chr 964)) (LaTeXMath "\\tau"),
  Mapping (Just (chr 965)) (LaTeXMath "\\upsilon"),
  Mapping (Just (chr 978)) (LaTeXMath "\\Upsilon"),
  Mapping (Just (chr 966)) (LaTeXMath "\\phi"),
  Mapping (Just (chr 934)) (LaTeXMath "\\Phi"),
  Mapping (Just (chr 981)) (LaTeXMath "\\varphi"),
  Mapping (Just (chr 967)) (LaTeXMath "\\chi"),
  Mapping (Just (chr 968)) (LaTeXMath "\\psi"),
  Mapping (Just (chr 936)) (LaTeXMath "\\Psi"),
  Mapping (Just (chr 969)) (LaTeXMath "\\omega"),
  Mapping (Just (chr 937)) (LaTeXMath "\\Omega"),
  Mapping (Just (chr 945)) (LaTeXMath "\\alpha"),
  Mapping (Just (chr 946)) (LaTeXMath "\\beta"),
  Mapping (Just (chr 947)) (LaTeXMath "\\gamma"),
  Mapping (Just (chr 915)) (LaTeXMath "\\Gamma"),
  Mapping (Just (chr 988)) (LaTeXMath "\\digamma"),
  Mapping (Just (chr 948)) (LaTeXMath "\\delta"),
  Mapping (Just (chr 916)) (LaTeXMath "\\Delta"),
  Mapping (Just (chr 949)) (LaTeXMath "\\epsilon"),
  Mapping (Just (chr 949)) (LaTeXMath "\\varepsilon"),
  Mapping (Just (chr 949)) (LaTeXMath "\\epsilon"),
  Mapping (Just (chr 950)) (LaTeXMath "\\zeta"),
  Mapping (Just (chr 951)) (LaTeXMath "\\eta"),
  Mapping (Just (chr 952)) (LaTeXMath "\\theta"),
  Mapping (Just (chr 920)) (LaTeXMath "\\Theta"),
  Mapping (Just (chr 977)) (LaTeXMath "\\vartheta"),
  Mapping (Just (chr 953)) (LaTeXMath "\\iota"),
  Mapping (Just (chr 954)) (LaTeXMath "\\kappa"),
  Mapping (Just (chr 1008)) (LaTeXMath "\\varkappa"),
  Mapping (Just (chr 955)) (LaTeXMath "\\lambda"),
  Mapping (Just (chr 923)) (LaTeXMath "\\Lambda"),
  Mapping (Just (chr 956)) (LaTeXMath "\\mu"),
  Mapping (Just (chr 957)) (LaTeXMath "\\nu"),
  Mapping (Just (chr 958)) (LaTeXMath "\\xi"),
  Mapping (Just (chr 926)) (LaTeXMath "\\Xi"),
  Mapping (Just (chr 960)) (LaTeXMath "\\pi"),
  Mapping (Just (chr 928)) (LaTeXMath "\\Pi"),
  Mapping (Just (chr 982)) (LaTeXMath "\\varpi"),
  Mapping (Just (chr 961)) (LaTeXMath "\\rho"),
  Mapping (Just (chr 1009)) (LaTeXMath "\\varrho"),
  Mapping (Just (chr 963)) (LaTeXMath "\\sigma"),
  Mapping (Just (chr 931)) (LaTeXMath "\\Sigma"),
  Mapping (Just (chr 962)) (LaTeXMath "\\varsigma"),
  Mapping (Just (chr 964)) (LaTeXMath "\\tau"),
  Mapping (Just (chr 965)) (LaTeXMath "\\upsilon"),
  Mapping (Just (chr 978)) (LaTeXMath "\\Upsilon"),
  Mapping (Just (chr 966)) (LaTeXMath "\\phi"),
  Mapping (Just (chr 934)) (LaTeXMath "\\Phi"),
  Mapping (Just (chr 981)) (LaTeXMath "\\varphi"),
  Mapping (Just (chr 967)) (LaTeXMath "\\chi"),
  Mapping (Just (chr 968)) (LaTeXMath "\\psi"),
  Mapping (Just (chr 936)) (LaTeXMath "\\Psi"),
  Mapping (Just (chr 969)) (LaTeXMath "\\omega"),
  Mapping (Just (chr 937)) (LaTeXMath "\\Omega"),
  Mapping (Just (chr 8736)) (LaTeXMath "\\angle"),
  Mapping (Just (chr 8737)) (LaTeXMath "\\measuredangle"),
  Mapping (Just (chr 8502)) (LaTeXMath "\\beth"),
  Mapping (Just (chr 8245)) (LaTeXMath "^\\backprime"),
  Mapping (Just (chr 8705)) (LaTeXMath "\\complement"),
  Mapping (Just (chr 8504)) (LaTeXMath "\\daleth"),
  Mapping (Just (chr 8467)) (LaTeXMath "\\ell"),
  Mapping (Just (chr 8709)) (LaTeXMath "\\emptyset"),
  Mapping (Just (chr 8503)) (LaTeXMath "\\gimel"),
  Mapping (Just (chr 8465)) (LaTeXMath "\\Im"),
  Mapping Nothing (LaTeXMath "\\imath"),
  Mapping Nothing (LaTeXMath "\\jmath"),
  Mapping (Just (chr 8708)) (LaTeXMath "\\nexists"),
  Mapping (Just (chr 9416)) (LaTeX "\\textcircled{S}"),
  Mapping (Just (chr 9416)) (LaTeXMath "\\circledS"),
  Mapping (Just (chr 8463)) (LaTeXMath "\\hbar"),
  Mapping (Just (chr 8476)) (LaTeXMath "\\Re"),
  Mapping (Just (chr 65128)) (LaTeXMath "\\smallsetminus"),
  Mapping Nothing (LaTeXMath "{'}"),
  Mapping (Just (chr 8472)) (LaTeXMath "\\wp"),
  Mapping (Just (chr 8720)) (LaTeXMath "\\amalg"),
  Mapping (Just (chr 8966)) (LaTeXMath "\\doublebarwedge"),
  Mapping (Just (chr 8892)) (LaTeXMath "\\barwedge"),
  Mapping (Just (chr 8914)) (LaTeXMath "\\Cap"),
  Mapping (Just (chr 8914)) (LaTeXMath "\\doublecap"),
  Mapping (Just (chr 8915)) (LaTeXMath "\\Cup"),
  Mapping (Just (chr 8915)) (LaTeXMath "\\doublecup"),
  Mapping (Just (chr 8910)) (LaTeXMath "\\curlyvee"),
  Mapping (Just (chr 8911)) (LaTeXMath "\\curlywedge"),
  Mapping (Just (chr 8900)) (LaTeXMath "\\diamond"),
  Mapping (Just (chr 8903)) (LaTeXMath "\\divideontimes"),
  Mapping (Just (chr 8890)) (LaTeXMath "\\intercal"),
  Mapping (Just (chr 8907)) (LaTeXMath "\\leftthreetimes"),
  Mapping (Just (chr 8905)) (LaTeXMath "\\ltimes"),
  Mapping (Just (chr 8863)) (LaTeXMath "\\boxminus"),
  Mapping (Just (chr 8859)) (LaTeXMath "\\circledast"),
  Mapping (Just (chr 8858)) (LaTeXMath "\\circledcirc"),
  Mapping (Just (chr 8861)) (LaTeXMath "\\circleddash"),
  Mapping (Just (chr 8857)) (LaTeXMath "\\odot"),
  Mapping (Just (chr 8854)) (LaTeXMath "\\ominus"),
  Mapping (Just (chr 8853)) (LaTeXMath "\\oplus"),
  Mapping (Just (chr 8856)) (LaTeXMath "\\oslash"),
  Mapping (Just (chr 8855)) (LaTeXMath "\\otimes"),
  Mapping (Just (chr 8862)) (LaTeXMath "\\boxplus"),
  Mapping (Just (chr 8724)) (LaTeXMath "\\dotplus"),
  Mapping (Just (chr 8908)) (LaTeXMath "\\rightthreetimes"),
  Mapping (Just (chr 8906)) (LaTeXMath "\\rtimes"),
  Mapping (Just (chr 8901)) (LaTeXMath "\\cdot"),
  Mapping (Just (chr 8865)) (LaTeXMath "\\boxdot"),
  Mapping (Just (chr 8726)) (LaTeXMath "\\setminus"),
  Mapping (Just (chr 8851)) (LaTeXMath "\\sqcap"),
  Mapping (Just (chr 8852)) (LaTeXMath "\\sqcup"),
  Mapping Nothing (LaTeXMath "\\smallsetminus"),
  Mapping (Just (chr 8902)) (LaTeXMath "\\star"),
  Mapping (Just (chr 8864)) (LaTeXMath "\\boxtimes"),
  Mapping (Just (chr 8868)) (LaTeXMath "\\top"),
  Mapping (Just (chr 8846)) (LaTeXMath "\\uplus"),
  Mapping (Just (chr 8768)) (LaTeXMath "\\wr"),
  Mapping (Just (chr 9711)) (LaTeX "\\textbigcircle"),
  Mapping (Just (chr 9711)) (LaTeXMath "\\bigcirc"),
  Mapping (Just (chr 9661)) (LaTeXMath "\\bigtriangledown"),
  Mapping (Just (chr 9651)) (LaTeXMath "\\bigtriangleup"),
  Mapping (Just (chr 8720)) (LaTeXMath "\\coprod"),
  Mapping (Just (chr 8719)) (LaTeXMath "\\prod"),
  Mapping (Just (chr 8721)) (LaTeXMath "\\sum"),
  Mapping (Just (chr 8778)) (LaTeXMath "\\approxeq"),
  Mapping (Just (chr 8781)) (LaTeXMath "\\asymp"),
  Mapping (Just (chr 8780)) (LaTeXMath "\\backcong"),
  Mapping (Just (chr 8717)) (LaTeXMath "\\backepsilon"),
  Mapping (Just (chr 8904)) (LaTeXMath "\\bowtie"),
  Mapping (Just (chr 8765)) (LaTeXMath "\\backsim"),
  Mapping (Just (chr 8909)) (LaTeXMath "\\backsimeq"),
  Mapping (Just (chr 8782)) (LaTeXMath "\\Bumpeq"),
  Mapping (Just (chr 8783)) (LaTeXMath "\\bumpeq"),
  Mapping (Just (chr 8791)) (LaTeXMath "\\circeq"),
  Mapping (Just (chr 8788)) (LaTeXMath ":="),
  Mapping (Just (chr 8926)) (LaTeXMath "\\curlyeqprec"),
  Mapping (Just (chr 8927)) (LaTeXMath "\\curlyeqsucc"),
  Mapping (Just (chr 8828)) (LaTeXMath "\\preccurlyeq"),
  Mapping (Just (chr 8867)) (LaTeXMath "\\dashv"),
  Mapping (Just (chr 8790)) (LaTeXMath "\\eqcirc"),
  Mapping (Just (chr 8789)) (LaTeXMath "=:"),
  Mapping (Just (chr 8785)) (LaTeXMath "\\doteqdot"),
  Mapping (Just (chr 8785)) (LaTeXMath "\\Doteq"),
  Mapping (Just (chr 8784)) (LaTeXMath "\\doteq"),
  Mapping (Just (chr 8786)) (LaTeXMath "\\fallingdotseq"),
  Mapping (Just (chr 8925)) (LaTeXMath "\\eqslantgtr"),
  Mapping (Just (chr 8924)) (LaTeXMath "\\eqslantless"),
  Mapping (Just (chr 8787)) (LaTeXMath "\\risingdotseq"),
  Mapping (Just (chr 8916)) (LaTeXMath "\\pitchfork"),
  Mapping (Just (chr 8994)) (LaTeXMath "\\frown"),
  Mapping Nothing (LaTeXMath "\\gtrapprox"),
  Mapping (Just (chr 8919)) (LaTeXMath "\\gtrdot"),
  Mapping (Just (chr 8807)) (LaTeXMath "\\geqq"),
  Mapping (Just (chr 8923)) (LaTeXMath "\\gtreqless"),
  Mapping (Just (chr 8923)) (LaTeXMath "\\gtreqqless"),
  Mapping Nothing (LaTeXMath "\\geqslant"),
  Mapping (Just (chr 8921)) (LaTeXMath "\\ggg"),
  Mapping (Just (chr 8921)) (LaTeXMath "\\gggtr"),
  Mapping (Just (chr 8823)) (LaTeXMath "\\gtrless"),
  Mapping (Just (chr 8819)) (LaTeXMath "\\gtrsim"),
  Mapping (Just (chr 8811)) (LaTeXMath "\\gg"),
  Mapping Nothing (LaTeXMath "\\lessapprox"),
  Mapping (Just (chr 8918)) (LaTeXMath "\\lessdot"),
  Mapping (Just (chr 8806)) (LaTeXMath "\\leqq"),
  Mapping (Just (chr 8922)) (LaTeXMath "\\lesseqqgtr"),
  Mapping (Just (chr 8922)) (LaTeXMath "\\lesseqgtr"),
  Mapping Nothing (LaTeXMath "\\leqslant"),
  Mapping (Just (chr 8822)) (LaTeXMath "\\lessgtr"),
  Mapping (Just (chr 8920)) (LaTeXMath "\\lll"),
  Mapping (Just (chr 8920)) (LaTeXMath "\\llless"),
  Mapping (Just (chr 8818)) (LaTeXMath "\\lesssim"),
  Mapping (Just (chr 8810)) (LaTeXMath "\\ll"),
  Mapping (Just (chr 8884)) (LaTeXMath "\\trianglelefteq"),
  Mapping (Just (chr 8739)) (LaTeXMath "\\mid"),
  Mapping (Just (chr 8871)) (LaTeXMath "\\models"),
  Mapping (Just (chr 8826)) (LaTeXMath "\\prec")
  ]

latexEntities2 = [
  Mapping Nothing (LaTeXMath "\\precapprox"),
  Mapping (Just (chr 8828)) (LaTeXMath "\\preceq"),
  Mapping (Just (chr 8830)) (LaTeXMath "\\precsim"),
  Mapping (Just (chr 8885)) (LaTeXMath "\\trianglerighteq"),
  Mapping Nothing (LaTeXMath "\\amalg"),
  Mapping Nothing (LaTeXMath "\\textstyle\\amalg"),
  Mapping (Just (chr 8827)) (LaTeXMath "\\succ"),
  Mapping Nothing (LaTeXMath "\\succapprox"),
  Mapping (Just (chr 8829)) (LaTeXMath "\\succcurlyeq"),
  Mapping (Just (chr 8829)) (LaTeXMath "\\succeq"),
  Mapping (Just (chr 8831)) (LaTeXMath "\\succsim"),
  Mapping Nothing (LaTeXMath "\\smallfrown"),
  Mapping Nothing (LaTeXMath "\\shortmid"),
  Mapping (Just (chr 8995)) (LaTeXMath "\\smile"),
  Mapping Nothing (LaTeXMath "\\shortparallel"),
  Mapping (Just (chr 8847)) (LaTeXMath "\\sqsubset"),
  Mapping (Just (chr 8849)) (LaTeXMath "\\sqsubseteq"),
  Mapping (Just (chr 8848)) (LaTeXMath "\\sqsupset"),
  Mapping (Just (chr 8850)) (LaTeXMath "\\sqsupseteq"),
  Mapping Nothing (LaTeXMath "\\smallsmile"),
  Mapping (Just (chr 8912)) (LaTeXMath "\\Subset"),
  Mapping (Just (chr 8838)) (LaTeXMath "\\subseteqq"),
  Mapping (Just (chr 8913)) (LaTeXMath "\\Supset"),
  Mapping (Just (chr 8839)) (LaTeXMath "\\supseteqq"),
  Mapping Nothing (LaTeXMath "\\thickapprox"),
  Mapping Nothing (LaTeXMath "\\thicksim"),
  Mapping (Just (chr 8796)) (LaTeXMath "\\triangleq"),
  Mapping (Just (chr 8812)) (LaTeXMath "\\between"),
  Mapping (Just (chr 8866)) (LaTeXMath "\\vdash"),
  Mapping (Just (chr 8873)) (LaTeXMath "\\Vdash"),
  Mapping (Just (chr 8872)) (LaTeXMath "\\vDash"),
  Mapping (Just (chr 8891)) (LaTeXMath "\\veebar"),
  Mapping (Just (chr 8882)) (LaTeXMath "\\vartriangleleft"),
  Mapping (Just (chr 8733)) (LaTeXMath "\\varpropto"),
  Mapping (Just (chr 8883)) (LaTeXMath "\\vartriangleright"),
  Mapping (Just (chr 8874)) (LaTeXMath "\\Vvdash"),
  Mapping Nothing (LaTeXMath "\\gnapprox"),
  Mapping (Just (chr 8809)) (LaTeXMath "\\gneq"),
  Mapping (Just (chr 8809)) (LaTeXMath "\\gneqq"),
  Mapping (Just (chr 8935)) (LaTeXMath "\\gnsim"),
  Mapping (Just (chr 8809)) (LaTeXMath "\\gvertneqq"),
  Mapping Nothing (LaTeXMath "\\lnapprox"),
  Mapping (Just (chr 8808)) (LaTeXMath "\\lneqq"),
  Mapping (Just (chr 8808)) (LaTeXMath "\\lneq"),
  Mapping (Just (chr 8934)) (LaTeXMath "\\lnsim"),
  Mapping (Just (chr 8808)) (LaTeXMath "\\lvertneqq"),
  Mapping (Just (chr 8777)) (LaTeXMath "\\not\\approx"),
  Mapping (Just (chr 8775)) (LaTeXMath "\\not\\cong"),
  Mapping (Just (chr 8775)) (LaTeXMath "\\ncong"),
  Mapping (Just (chr 8802)) (LaTeXMath "\\not\\equiv"),
  Mapping Nothing (LaTeXMath "\\ngeqq"),
  Mapping (Just (chr 8817)) (LaTeXMath "\\not\\geq"),
  Mapping (Just (chr 8817)) (LaTeXMath "\\ngeq"),
  Mapping (Just (chr 8817)) (LaTeXMath "\\ngeqslant"),
  Mapping (Just (chr 8815)) (LaTeXMath "\\not&gt;"),
  Mapping (Just (chr 8815)) (LaTeXMath "\\ngtr"),
  Mapping (Just (chr 8816)) (LaTeXMath "\\not\\leq"),
  Mapping (Just (chr 8816)) (LaTeXMath "\\nleq"),
  Mapping Nothing (LaTeXMath "\\nleqq"),
  Mapping (Just (chr 8816)) (LaTeXMath "\\nleqslant"),
  Mapping (Just (chr 8814)) (LaTeXMath "\\not&lt;"),
  Mapping (Just (chr 8814)) (LaTeXMath "\\nless"),
  Mapping (Just (chr 8938)) (LaTeXMath "\\ntriangleleft"),
  Mapping (Just (chr 8940)) (LaTeXMath "\\ntrianglelefteq"),
  Mapping (Just (chr 8740)) (LaTeXMath "\\nmid"),
  Mapping (Just (chr 8742)) (LaTeXMath "\\nparallel"),
  Mapping (Just (chr 8832)) (LaTeXMath "\\not\\prec"),
  Mapping (Just (chr 8832)) (LaTeXMath "\\nprec"),
  Mapping (Just (chr 8928)) (LaTeXMath "\\not\\preceq"),
  Mapping (Just (chr 8928)) (LaTeXMath "\\npreceq"),
  Mapping (Just (chr 8939)) (LaTeXMath "\\ntriangleright"),
  Mapping (Just (chr 8941)) (LaTeXMath "\\ntrianglerighteq"),
  Mapping (Just (chr 8833)) (LaTeXMath "\\not\\succ"),
  Mapping (Just (chr 8833)) (LaTeXMath "\\nsucc"),
  Mapping (Just (chr 8929)) (LaTeXMath "\\not\\succeq"),
  Mapping (Just (chr 8929)) (LaTeXMath "\\nsucceq"),
  Mapping (Just (chr 8769)) (LaTeXMath "\\not\\sim"),
  Mapping (Just (chr 8769)) (LaTeXMath "\\nsim"),
  Mapping (Just (chr 8772)) (LaTeXMath "\\not\\simeq"),
  Mapping Nothing (LaTeXMath "\\nshortmid"),
  Mapping Nothing (LaTeXMath "\\nshortparallel"),
  Mapping (Just (chr 8836)) (LaTeXMath "\\not\\subset"),
  Mapping (Just (chr 8840)) (LaTeXMath "\\not\\subseteq"),
  Mapping (Just (chr 8840)) (LaTeXMath "\\nsubseteq"),
  Mapping (Just (chr 8840)) (LaTeXMath "\\nsubseteqq"),
  Mapping (Just (chr 8837)) (LaTeXMath "\\not\\supset"),
  Mapping (Just (chr 8841)) (LaTeXMath "\\nsupseteqq"),
  Mapping (Just (chr 8841)) (LaTeXMath "\\not\\supseteq"),
  Mapping (Just (chr 8841)) (LaTeXMath "\\nsupseteq"),
  Mapping (Just (chr 8876)) (LaTeXMath "\\nvdash"),
  Mapping (Just (chr 8877)) (LaTeXMath "\\nvDash"),
  Mapping (Just (chr 8879)) (LaTeXMath "\\nVDash"),
  Mapping (Just (chr 8878)) (LaTeXMath "\\nVdash"),
  Mapping Nothing (LaTeXMath "\\precnapprox"),
  Mapping Nothing (LaTeXMath "\\precneqq"),
  Mapping (Just (chr 8936)) (LaTeXMath "\\precnsim"),
  Mapping Nothing (LaTeXMath "\\succnapprox"),
  Mapping Nothing (LaTeXMath "\\succneqq"),
  Mapping (Just (chr 8937)) (LaTeXMath "\\succnsim"),
  Mapping (Just (chr 8842)) (LaTeXMath "\\subsetneq"),
  Mapping (Just (chr 8842)) (LaTeXMath "\\subsetneqq"),
  Mapping (Just (chr 8843)) (LaTeXMath "\\supsetneq"),
  Mapping (Just (chr 8843)) (LaTeXMath "\\supsetneqq"),
  Mapping Nothing (LaTeXMath "\\varsubsetneqq"),
  Mapping Nothing (LaTeXMath "\\varsubsetneq"),
  Mapping Nothing (LaTeXMath "\\varsupsetneq"),
  Mapping Nothing (LaTeXMath "\\varsupsetneqq"),
  Mapping (Just (chr 8630)) (LaTeXMath "\\curvearrowleft"),
  Mapping (Just (chr 8631)) (LaTeXMath "\\curvearrowright"),
  Mapping (Just (chr 8659)) (LaTeXMath "\\Downarrow"),
  Mapping (Just (chr 8650)) (LaTeXMath "\\downdownarrows"),
  Mapping (Just (chr 8643)) (LaTeXMath "\\downharpoonleft"),
  Mapping (Just (chr 8642)) (LaTeXMath "\\downharpoonright"),
  Mapping (Just (chr 8666)) (LaTeXMath "\\Lleftarrow"),
  Mapping (Just (chr 8606)) (LaTeXMath "\\twoheadleftarrow"),
  Mapping (Just (chr 8647)) (LaTeXMath "\\leftleftarrows"),
  Mapping (Just (chr 8617)) (LaTeXMath "\\hookleftarrow"),
  Mapping (Just (chr 8619)) (LaTeXMath "\\looparrowleft"),
  Mapping (Just (chr 8610)) (LaTeXMath "\\leftarrowtail"),
  Mapping (Just (chr 8637)) (LaTeXMath "\\leftharpoondown"),
  Mapping (Just (chr 8636)) (LaTeXMath "\\leftharpoonup"),
  Mapping (Just (chr 8660)) (LaTeXMath "\\Leftrightarrow"),
  Mapping (Just (chr 8596)) (LaTeXMath "\\leftrightarrow"),
  Mapping (Just (chr 8646)) (LaTeXMath "\\leftrightarrows"),
  Mapping (Just (chr 8644)) (LaTeXMath "\\rightleftarrows"),
  Mapping (Just (chr 8621)) (LaTeXMath "\\leftrightsquigarrow"),
  Mapping (Just (chr 8652)) (LaTeXMath "\\rightleftharpoons"),
  Mapping (Just (chr 8651)) (LaTeXMath "\\leftrightharpoons"),
  Mapping (Just (chr 8624)) (LaTeXMath "\\Lsh"),
  Mapping (Just (chr 8614)) (LaTeXMath "\\mapsto"),
  Mapping (Just (chr 8888)) (LaTeXMath "\\multimap"),
  Mapping (Just (chr 8599)) (LaTeXMath "\\nearrow"),
  Mapping (Just (chr 8653)) (LaTeXMath "\\nLeftarrow"),
  Mapping (Just (chr 8602)) (LaTeXMath "\\nleftarrow"),
  Mapping (Just (chr 8654)) (LaTeXMath "\\nLeftrightarrow"),
  Mapping (Just (chr 8622)) (LaTeXMath "\\nleftrightarrow"),
  Mapping (Just (chr 8603)) (LaTeXMath "\\nrightarrow"),
  Mapping (Just (chr 8655)) (LaTeXMath "\\nRightarrow"),
  Mapping (Just (chr 8598)) (LaTeXMath "\\nwarrow"),
  Mapping (Just (chr 8634)) (LaTeXMath "\\circlearrowleft"),
  Mapping (Just (chr 8635)) (LaTeXMath "\\circlearrowright"),
  Mapping (Just (chr 8667)) (LaTeXMath "\\Rrightarrow"),
  Mapping (Just (chr 8608)) (LaTeXMath "\\twoheadrightarrow"),
  Mapping (Just (chr 8649)) (LaTeXMath "\\rightrightarrows"),
  Mapping (Just (chr 8618)) (LaTeXMath "\\hookrightarrow"),
  Mapping (Just (chr 8620)) (LaTeXMath "\\looparrowright"),
  Mapping (Just (chr 8611)) (LaTeXMath "\\rightarrowtail"),
  Mapping (Just (chr 8669)) (LaTeXMath "\\rightsquigarrow"),
  Mapping (Just (chr 8641)) (LaTeXMath "\\rightharpoondown"),
  Mapping (Just (chr 8640)) (LaTeXMath "\\rightharpoonup"),
  Mapping (Just (chr 8625)) (LaTeXMath "\\Rsh"),
  Mapping (Just (chr 8600)) (LaTeXMath "\\searrow"),
  Mapping (Just (chr 8601)) (LaTeXMath "\\swarrow"),
  Mapping (Just (chr 8657)) (LaTeXMath "\\Uparrow"),
  Mapping (Just (chr 8648)) (LaTeXMath "\\upuparrows"),
  Mapping (Just (chr 8661)) (LaTeXMath "\\Updownarrow"),
  Mapping (Just (chr 8597)) (LaTeXMath "\\updownarrow"),
  Mapping (Just (chr 8639)) (LaTeXMath "\\upharpoonleft"),
  Mapping (Just (chr 8638)) (LaTeXMath "\\upharpoonright"),
  Mapping Nothing (LaTeXMath "\\Longleftarrow"),
  Mapping Nothing (LaTeXMath "\\Longleftrightarrow"),
  Mapping Nothing (LaTeXMath "\\longleftrightarrow"),
  Mapping Nothing (LaTeXMath "\\Longrightarrow"),
  Mapping (Just (chr 8969)) (LaTeXMath "\\rceil"),
  Mapping (Just (chr 8971)) (LaTeXMath "\\rfloor"),
  Mapping Nothing (LaTeXMath "\\rlap{$>$}\\,)"),
  Mapping (Just (chr 8989)) (LaTeXMath "\\urcorner"),
  Mapping (Just (chr 8991)) (LaTeXMath "\\lrcorner"),
  Mapping (Just (chr 8968)) (LaTeXMath "\\lceil"),
  Mapping (Just (chr 8970)) (LaTeXMath "\\lfloor"),
  Mapping Nothing (LaTeXMath "\\rlap{$>$}\\,("),
  Mapping (Just (chr 8988)) (LaTeXMath "\\ulcorner"),
  Mapping (Just (chr 8990)) (LaTeXMath "\\llcorner"),
  Mapping (Just (chr 225)) (LaTeX "\\'{a}"),
  Mapping (Just (chr 193)) (LaTeX "\\'{A}"),
  Mapping (Just (chr 226)) (LaTeX "\\^{a}"),
  Mapping (Just (chr 194)) (LaTeX "\\^{A}"),
  Mapping (Just (chr 224)) (LaTeX "\\`{a}"),
  Mapping (Just (chr 192)) (LaTeX "\\`{A}"),
  Mapping (Just (chr 229)) (LaTeX "\\aa"),
  Mapping (Just (chr 197)) (LaTeX "\\AA"),
  Mapping (Just (chr 227)) (LaTeX "\\~{a}"),
  Mapping (Just (chr 195)) (LaTeX "\\~{A}"),
  Mapping (Just (chr 228)) (LaTeX "\\\"{a}"),
  Mapping (Just (chr 196)) (LaTeX "\\\"{A}"),
  Mapping (Just (chr 230)) (LaTeX "\\ae"),
  Mapping (Just (chr 198)) (LaTeX "\\AE"),
  Mapping (Just (chr 231)) (LaTeX "\\c{c}"),
  Mapping (Just (chr 199)) (LaTeX "\\c{C}"),
  Mapping (Just (chr 240)) (LaTeX "\\dh"),
  Mapping (Just (chr 240)) (LaTeXMath "\\eth"),
  Mapping (Just (chr 208)) (LaTeX "\\DH"),
  Mapping (Just (chr 208)) (LaTeX "\\DH"),
  Mapping (Just (chr 233)) (LaTeX "\\'{e}"),
  Mapping (Just (chr 201)) (LaTeX "\\'{E}"),
  Mapping (Just (chr 234)) (LaTeX "\\^{e}"),
  Mapping (Just (chr 202)) (LaTeX "\\^{E}"),
  Mapping (Just (chr 232)) (LaTeX "\\`{e}"),
  Mapping (Just (chr 200)) (LaTeX "\\`{E}"),
  Mapping (Just (chr 235)) (LaTeX "\\\"{e}"),
  Mapping (Just (chr 203)) (LaTeX "\\\"{E}"),
  Mapping (Just (chr 237)) (LaTeX "\\'{\\i}"),
  Mapping (Just (chr 205)) (LaTeX "\\'{I}"),
  Mapping (Just (chr 238)) (LaTeX "\\^{\\i}"),
  Mapping (Just (chr 206)) (LaTeX "\\^{I}"),
  Mapping (Just (chr 236)) (LaTeX "\\`{\\i}"),
  Mapping (Just (chr 204)) (LaTeX "\\`{I}"),
  Mapping (Just (chr 239)) (LaTeX "\\\"{\\i}"),
  Mapping (Just (chr 207)) (LaTeX "\\\"{I}"),
  Mapping (Just (chr 241)) (LaTeX "\\~{n}"),
  Mapping (Just (chr 209)) (LaTeX "\\~{N}"),
  Mapping (Just (chr 243)) (LaTeX "\\'{o}"),
  Mapping (Just (chr 211)) (LaTeX "\\'{O}"),
  Mapping (Just (chr 244)) (LaTeX "\\^{o}"),
  Mapping (Just (chr 212)) (LaTeX "\\^{O}"),
  Mapping (Just (chr 242)) (LaTeX "\\`{o}"),
  Mapping (Just (chr 210)) (LaTeX "\\`{O}"),
  Mapping (Just (chr 248)) (LaTeX "\\o"),
  Mapping (Just (chr 216)) (LaTeX "\\O"),
  Mapping (Just (chr 245)) (LaTeX "\\~{o}"),
  Mapping (Just (chr 213)) (LaTeX "\\~{O}"),
  Mapping (Just (chr 246)) (LaTeX "\\\"{o}"),
  Mapping (Just (chr 214)) (LaTeX "\\\"{O}"),
  Mapping (Just (chr 223)) (LaTeX "\\ss"),
  Mapping (Just (chr 254)) (LaTeX "\\th"),
  Mapping (Just (chr 254)) (LaTeX "\\thorn"),
  Mapping (Just (chr 222)) (LaTeX "\\TH"),
  Mapping (Just (chr 222)) (LaTeX "\\Thorn"),
  Mapping (Just (chr 250)) (LaTeX "\\'{u}"),
  Mapping (Just (chr 218)) (LaTeX "\\'{U}"),
  Mapping (Just (chr 251)) (LaTeX "\\^{u}"),
  Mapping (Just (chr 219)) (LaTeX "\\^{U}"),
  Mapping (Just (chr 249)) (LaTeX "\\`{u}"),
  Mapping (Just (chr 217)) (LaTeX "\\`{U}"),
  Mapping (Just (chr 252)) (LaTeX "\\\"{u}"),
  Mapping (Just (chr 220)) (LaTeX "\\\"{U}"),
  Mapping (Just (chr 253)) (LaTeX "\\'{y}"),
  Mapping (Just (chr 221)) (LaTeX "\\'{Y}"),
  Mapping (Just (chr 255)) (LaTeX "\\\"{y}"),
  Mapping (Just (chr 259)) (LaTeX "\\u{a}"),
  Mapping (Just (chr 258)) (LaTeX "\\u{A}"),
  Mapping (Just (chr 257)) (LaTeX "\\={a}"),
  Mapping (Just (chr 256)) (LaTeX "\\={A}"),
  Mapping (Just (chr 261)) (LaTeX "\\k{a}"),
  Mapping (Just (chr 260)) (LaTeX "\\k{A}"),
  Mapping (Just (chr 263)) (LaTeX "\\'{c}"),
  Mapping (Just (chr 262)) (LaTeX "\\'{C}"),
  Mapping (Just (chr 269)) (LaTeX "\\v{c}"),
  Mapping (Just (chr 268)) (LaTeX "\\v{C}"),
  Mapping (Just (chr 265)) (LaTeX "\\^{c}"),
  Mapping (Just (chr 264)) (LaTeX "\\^{C}"),
  Mapping (Just (chr 267)) (LaTeX "\\.{c}"),
  Mapping (Just (chr 266)) (LaTeX "\\.{C}"),
  Mapping (Just (chr 271)) (LaTeX "\\v{d}"),
  Mapping (Just (chr 270)) (LaTeX "\\v{D}"),
  Mapping (Just (chr 273)) (LaTeX "\\dj"),
  Mapping (Just (chr 272)) (LaTeX "\\DJ"),
  Mapping (Just (chr 283)) (LaTeX "\\v{e}"),
  Mapping (Just (chr 282)) (LaTeX "\\v{E}"),
  Mapping (Just (chr 279)) (LaTeX "\\.{e}"),
  Mapping (Just (chr 278)) (LaTeX "\\.{E}"),
  Mapping (Just (chr 275)) (LaTeX "\\={e}"),
  Mapping (Just (chr 274)) (LaTeX "\\={E}"),
  Mapping (Just (chr 281)) (LaTeX "\\k{e}"),
  Mapping (Just (chr 280)) (LaTeX "\\k{E}"),
  Mapping (Just (chr 501)) (LaTeX "\\'{g}"),
  Mapping (Just (chr 287)) (LaTeX "\\u{g}"),
  Mapping (Just (chr 286)) (LaTeX "\\u{G}"),
  Mapping (Just (chr 290)) (LaTeX "\\c{G}"),
  Mapping (Just (chr 285)) (LaTeX "\\^{g}"),
  Mapping (Just (chr 284)) (LaTeX "\\^{G}"),
  Mapping (Just (chr 289)) (LaTeX "\\.{g}"),
  Mapping (Just (chr 288)) (LaTeX "\\.{G}"),
  Mapping (Just (chr 293)) (LaTeX "\\^{h}"),
  Mapping (Just (chr 292)) (LaTeX "\\^{H}"),
  Mapping (Just (chr 295)) (LaTeX "\\hstrok"),
  Mapping (Just (chr 294)) (LaTeX "\\Hstrok"),
  Mapping (Just (chr 304)) (LaTeX "\\.{I}"),
  Mapping (Just (chr 298)) (LaTeX "\\={I}"),
  Mapping (Just (chr 299)) (LaTeX "\\={\\i}"),
  Mapping (Just (chr 307)) (LaTeX "i\\kern -.15em j"),
  Mapping (Just (chr 306)) (LaTeX "I\\kern -.15em J"),
  Mapping (Just (chr 305)) (LaTeX "\\i"),
  Mapping (Just (chr 303)) (LaTeX "\\k{i}"),
  Mapping (Just (chr 302)) (LaTeX "\\k{I}"),
  Mapping (Just (chr 297)) (LaTeX "\\~{\\i}"),
  Mapping (Just (chr 296)) (LaTeX "\\~{I}"),
  Mapping (Just (chr 309)) (LaTeX "\\^{\\j}"),
  Mapping (Just (chr 308)) (LaTeX "\\^{J}"),
  Mapping (Just (chr 311)) (LaTeX "\\c{k}"),
  Mapping (Just (chr 310)) (LaTeX "\\c{K}"),
  Mapping (Just (chr 312)) (LaTeX "\\textsc{k}"),
  Mapping (Just (chr 314)) (LaTeX "\\'{l}"),
  Mapping (Just (chr 313)) (LaTeX "\\'{L}"),
  Mapping (Just (chr 318)) (LaTeX "\\v{l}"),
  Mapping (Just (chr 317)) (LaTeX "\\v{L}"),
  Mapping (Just (chr 316)) (LaTeX "\\c{l}"),
  Mapping (Just (chr 315)) (LaTeX "\\c{L}"),
  Mapping (Just (chr 320)) (LaTeX "\\lmidot"),
  Mapping (Just (chr 319)) (LaTeX "\\Lmidot"),
  Mapping (Just (chr 322)) (LaTeX "\\l"),
  Mapping (Just (chr 321)) (LaTeX "\\L"),
  Mapping (Just (chr 324)) (LaTeX "\\'{n}"),
  Mapping (Just (chr 323)) (LaTeX "\\'{N}"),
  Mapping (Just (chr 331)) (LaTeX "\\ng"),
  Mapping (Just (chr 330)) (LaTeX "\\NG"),
  Mapping (Just (chr 329)) (LaTeX "n\\kern-.2em\\textsf{'}"),
  Mapping (Just (chr 329)) (LaTeX "n{'}"),
  Mapping (Just (chr 328)) (LaTeX "\\v{n}"),
  Mapping (Just (chr 327)) (LaTeX "\\v{N}"),
  Mapping (Just (chr 326)) (LaTeX "\\c{n}"),
  Mapping (Just (chr 325)) (LaTeX "\\c{N}"),
  Mapping (Just (chr 337)) (LaTeX "\\H{o}"),
  Mapping (Just (chr 336)) (LaTeX "\\H{O}"),
  Mapping (Just (chr 332)) (LaTeX "\\={O}"),
  Mapping (Just (chr 333)) (LaTeX "\\={o}"),
  Mapping (Just (chr 339)) (LaTeX "\\oe"),
  Mapping (Just (chr 338)) (LaTeX "\\OE"),
  Mapping (Just (chr 341)) (LaTeX "\\'{r}"),
  Mapping (Just (chr 340)) (LaTeX "\\'{R}"),
  Mapping (Just (chr 345)) (LaTeX "\\v{r}"),
  Mapping (Just (chr 344)) (LaTeX "\\v{R}"),
  Mapping (Just (chr 343)) (LaTeX "\\c{r}"),
  Mapping (Just (chr 342)) (LaTeX "\\c{R}"),
  Mapping (Just (chr 347)) (LaTeX "\\'{s}"),
  Mapping (Just (chr 346)) (LaTeX "\\'{S}"),
  Mapping (Just (chr 353)) (LaTeX "\\v{s}"),
  Mapping (Just (chr 352)) (LaTeX "\\v{S}"),
  Mapping (Just (chr 351)) (LaTeX "\\c{s}"),
  Mapping (Just (chr 350)) (LaTeX "\\c{S}"),
  Mapping (Just (chr 349)) (LaTeX "\\^{s}"),
  Mapping (Just (chr 348)) (LaTeX "\\^{S}"),
  Mapping (Just (chr 357)) (LaTeX "\\v{t}"),
  Mapping (Just (chr 356)) (LaTeX "\\v{T}"),
  Mapping (Just (chr 355)) (LaTeX "\\c{t}"),
  Mapping (Just (chr 354)) (LaTeX "\\c{T}"),
  Mapping (Just (chr 359)) (LaTeX "\\tstrok"),
  Mapping (Just (chr 358)) (LaTeX "\\Tstrok"),
  Mapping (Just (chr 365)) (LaTeX "\\u{u}"),
  Mapping (Just (chr 364)) (LaTeX "\\u{U}"),
  Mapping (Just (chr 369)) (LaTeX "\\H{u}"),
  Mapping (Just (chr 368)) (LaTeX "\\H{U}"),
  Mapping (Just (chr 363)) (LaTeX "\\={u}"),
  Mapping (Just (chr 362)) (LaTeX "\\={U}"),
  Mapping (Just (chr 371)) (LaTeX "\\k{u}"),
  Mapping (Just (chr 370)) (LaTeX "\\k{U}"),
  Mapping (Just (chr 367)) (LaTeX "\\r{u}"),
  Mapping (Just (chr 366)) (LaTeX "\\r{U}"),
  Mapping (Just (chr 361)) (LaTeX "\\~{u}"),
  Mapping (Just (chr 360)) (LaTeX "\\~{U}"),
  Mapping (Just (chr 373)) (LaTeX "\\^{w}"),
  Mapping (Just (chr 372)) (LaTeX "\\^{W}"),
  Mapping (Just (chr 375)) (LaTeX "\\^{y}"),
  Mapping (Just (chr 374)) (LaTeX "\\^{Y}"),
  Mapping (Just (chr 376)) (LaTeX "\\\"{Y}"),
  Mapping (Just (chr 378)) (LaTeX "\\'{z}"),
  Mapping (Just (chr 377)) (LaTeX "\\'{Z}"),
  Mapping (Just (chr 382)) (LaTeX "\\v{z}"),
  Mapping (Just (chr 381)) (LaTeX "\\v{Z}"),
  Mapping (Just (chr 380)) (LaTeX "\\.{z}"),
  Mapping (Just (chr 379)) (LaTeX "\\.{Z}"),
  Mapping (Just (chr 180)) (LaTeX "\\'{}"),
  Mapping (Just (chr 180)) (LaTeX "\\textasciiacute"),
  Mapping (Just (chr 180)) (LaTeXMath "\\acute{}"),
  Mapping (Just (chr 728)) (LaTeX "\\u{}"),
  Mapping (Just (chr 728)) (LaTeX "\\textasciibreve"),
  Mapping (Just (chr 728)) (LaTeXMath "\\breve{}"),
  Mapping (Just (chr 711)) (LaTeX "\\v{}"),
  Mapping (Just (chr 711)) (LaTeX "\\textasciicaron"),
  Mapping (Just (chr 711)) (LaTeXMath "\\check{}"),
  Mapping (Just (chr 184)) (LaTeX "\\c{}"),
  Mapping (Just (chr 94)) (LaTeX "\\^{}"),
  Mapping (Just (chr 94)) (LaTeX "\\textasciicircum"),
  Mapping (Just (chr 94)) (LaTeXMath "\\hat{}"),
  Mapping (Just (chr 733)) (LaTeX "\\H{}"),
  Mapping (Just (chr 733)) (LaTeX "\\textacutedbl"),
  Mapping (Just (chr 168)) (LaTeX "\\\"{}"),
  Mapping (Just (chr 168)) (LaTeX "\\textasciidieresis"),
  Mapping (Just (chr 168)) (LaTeXMath "\\ddot{}"),
  Mapping (Just (chr 729)) (LaTeX "\\.{}"),
  Mapping (Just (chr 729)) (LaTeXMath "\\dot{}"),
  Mapping (Just (chr 96)) (LaTeX "\\`{}"),
  Mapping (Just (chr 96)) (LaTeX "\\textasciigrave"),
  Mapping (Just (chr 96)) (LaTeXMath "\\grave{}"),
  Mapping (Just (chr 175)) (LaTeX "\\={}"),
  Mapping (Just (chr 175)) (LaTeX "\\textasciimacron"),
  Mapping (Just (chr 175)) (LaTeXMath "\\bar{}"),
  Mapping (Just (chr 731)) (LaTeX "\\k{}"),
  Mapping (Just (chr 730)) (LaTeX "\\r{}"),
  Mapping (Just (chr 126)) (LaTeX "\\~{}"),
  Mapping (Just (chr 126)) (LaTeX "\\textasciitilde"),
  Mapping (Just (chr 126)) (LaTeX "\\texttildelow"),
  Mapping (Just (chr 126)) (LaTeX "\\raise.5ex\\hbox{\\texttildelow}"),
  Mapping (Just (chr 126)) (LaTeXMath "\\tilde{}"),
  Mapping (Just (chr 1072)) (LaTeX "a"),
  Mapping (Just (chr 1072)) (LaTeX "\\cyra"),
  Mapping (Just (chr 1040)) (LaTeX "A"),
  Mapping (Just (chr 1040)) (LaTeX "\\CYRA"),
  Mapping (Just (chr 1073)) (LaTeX "b"),
  Mapping (Just (chr 1073)) (LaTeX "\\cyrb"),
  Mapping (Just (chr 1041)) (LaTeX "B"),
  Mapping (Just (chr 1041)) (LaTeX "\\CYRB"),
  Mapping (Just (chr 1074)) (LaTeX "v"),
  Mapping (Just (chr 1074)) (LaTeX "\\cyrv"),
  Mapping (Just (chr 1042)) (LaTeX "V"),
  Mapping (Just (chr 1042)) (LaTeX "\\CYRV"),
  Mapping (Just (chr 1075)) (LaTeX "g"),
  Mapping (Just (chr 1075)) (LaTeX "\\cyrg"),
  Mapping (Just (chr 1043)) (LaTeX "G"),
  Mapping (Just (chr 1043)) (LaTeX "\\CYRG"),
  Mapping (Just (chr 1076)) (LaTeX "d"),
  Mapping (Just (chr 1076)) (LaTeX "\\cyrd"),
  Mapping (Just (chr 1044)) (LaTeX "D"),
  Mapping (Just (chr 1044)) (LaTeX "\\CYRD"),
  Mapping (Just (chr 1077)) (LaTeX "e"),
  Mapping (Just (chr 1077)) (LaTeX "\\cyre"),
  Mapping (Just (chr 1045)) (LaTeX "E"),
  Mapping (Just (chr 1045)) (LaTeX "\\CYRE"),
  Mapping (Just (chr 1105)) (LaTeX "\\\"{e}"),
  Mapping (Just (chr 1105)) (LaTeX "\\cyryo"),
  Mapping (Just (chr 1025)) (LaTeX "\\\"{E}"),
  Mapping (Just (chr 1025)) (LaTeX "\\CYRYO"),
  Mapping (Just (chr 1078)) (LaTeX "zh"),
  Mapping (Just (chr 1078)) (LaTeX "\\cyrzh"),
  Mapping (Just (chr 1046)) (LaTeX "Zh"),
  Mapping (Just (chr 1046)) (LaTeX "\\CYRZH"),
  Mapping (Just (chr 1079)) (LaTeX "z"),
  Mapping (Just (chr 1079)) (LaTeX "\\cyrz"),
  Mapping (Just (chr 1047)) (LaTeX "Z"),
  Mapping (Just (chr 1047)) (LaTeX "\\CYRZ"),
  Mapping (Just (chr 1080)) (LaTeX "i"),
  Mapping (Just (chr 1080)) (LaTeX "\\cyri"),
  Mapping (Just (chr 1048)) (LaTeX "I"),
  Mapping (Just (chr 1048)) (LaTeX "\\CYRI"),
  Mapping (Just (chr 1081)) (LaTeX "\\u{i}"),
  Mapping (Just (chr 1081)) (LaTeX "\\cyrishrt"),
  Mapping (Just (chr 1049)) (LaTeX "\\u{I}"),
  Mapping (Just (chr 1049)) (LaTeX "\\CYRISHRT"),
  Mapping (Just (chr 1082)) (LaTeX "k"),
  Mapping (Just (chr 1082)) (LaTeX "\\cyrk"),
  Mapping (Just (chr 1050)) (LaTeX "K"),
  Mapping (Just (chr 1050)) (LaTeX "\\CYRK"),
  Mapping (Just (chr 1083)) (LaTeX "l"),
  Mapping (Just (chr 1083)) (LaTeX "\\cyrl"),
  Mapping (Just (chr 1051)) (LaTeX "L"),
  Mapping (Just (chr 1051)) (LaTeX "\\CYRL"),
  Mapping (Just (chr 1084)) (LaTeX "m"),
  Mapping (Just (chr 1084)) (LaTeX "\\cyrm"),
  Mapping (Just (chr 1052)) (LaTeX "M"),
  Mapping (Just (chr 1052)) (LaTeX "\\CYRM"),
  Mapping (Just (chr 1085)) (LaTeX "n"),
  Mapping (Just (chr 1085)) (LaTeX "\\cyrn"),
  Mapping (Just (chr 1053)) (LaTeX "N"),
  Mapping (Just (chr 1053)) (LaTeX "\\CYRN"),
  Mapping (Just (chr 1086)) (LaTeX "o"),
  Mapping (Just (chr 1086)) (LaTeX "\\cyro"),
  Mapping (Just (chr 1054)) (LaTeX "O"),
  Mapping (Just (chr 1054)) (LaTeX "\\CYRO"),
  Mapping (Just (chr 1087)) (LaTeX "p"),
  Mapping (Just (chr 1087)) (LaTeX "\\cyrp"),
  Mapping (Just (chr 1055)) (LaTeX "P"),
  Mapping (Just (chr 1055)) (LaTeX "\\CYRP"),
  Mapping (Just (chr 1088)) (LaTeX "r"),
  Mapping (Just (chr 1088)) (LaTeX "\\cyrr"),
  Mapping (Just (chr 1056)) (LaTeX "R"),
  Mapping (Just (chr 1056)) (LaTeX "\\CYRR"),
  Mapping (Just (chr 1089)) (LaTeX "s"),
  Mapping (Just (chr 1089)) (LaTeX "\\cyrs"),
  Mapping (Just (chr 1057)) (LaTeX "S"),
  Mapping (Just (chr 1057)) (LaTeX "\\CYRS"),
  Mapping (Just (chr 1090)) (LaTeX "t"),
  Mapping (Just (chr 1090)) (LaTeX "\\cyrt"),
  Mapping (Just (chr 1058)) (LaTeX "T"),
  Mapping (Just (chr 1058)) (LaTeX "\\CYRT"),
  Mapping (Just (chr 1091)) (LaTeX "u"),
  Mapping (Just (chr 1091)) (LaTeX "\\cyru"),
  Mapping (Just (chr 1059)) (LaTeX "U"),
  Mapping (Just (chr 1059)) (LaTeX "\\CYRU"),
  Mapping (Just (chr 1092)) (LaTeX "f"),
  Mapping (Just (chr 1092)) (LaTeX "\\cyrf"),
  Mapping (Just (chr 1060)) (LaTeX "F"),
  Mapping (Just (chr 1060)) (LaTeX "\\CYRF"),
  Mapping (Just (chr 1093)) (LaTeX "kh"),
  Mapping (Just (chr 1093)) (LaTeX "\\cyrh"),
  Mapping (Just (chr 1061)) (LaTeX "Kh"),
  Mapping (Just (chr 1061)) (LaTeX "\\CYRH"),
  Mapping (Just (chr 1094)) (LaTeX "ts"),
  Mapping (Just (chr 1094)) (LaTeX "\\cyrc"),
  Mapping (Just (chr 1062)) (LaTeX "Ts"),
  Mapping (Just (chr 1062)) (LaTeX "\\CYRC"),
  Mapping (Just (chr 1095)) (LaTeX "ch"),
  Mapping (Just (chr 1095)) (LaTeX "\\cyrch"),
  Mapping (Just (chr 1063)) (LaTeX "Ch"),
  Mapping (Just (chr 1063)) (LaTeX "\\CYRCH"),
  Mapping (Just (chr 1096)) (LaTeX "sh"),
  Mapping (Just (chr 1096)) (LaTeX "\\cyrsh"),
  Mapping (Just (chr 1064)) (LaTeX "Sh"),
  Mapping (Just (chr 1064)) (LaTeX "\\CYRSH"),
  Mapping (Just (chr 1097)) (LaTeX "shch"),
  Mapping (Just (chr 1097)) (LaTeX "\\cyrshch"),
  Mapping (Just (chr 1065)) (LaTeX "Shch"),
  Mapping (Just (chr 1065)) (LaTeX "\\CYRSHCH"),
  Mapping (Just (chr 1098)) (LaTeX "\\cdprime"),
  Mapping (Just (chr 1098)) (LaTeX "\\cyrhrdsn"),
  Mapping (Just (chr 1066)) (LaTeX "\\Cdprime"),
  Mapping (Just (chr 1066)) (LaTeX "\\CYRHRDSN"),
  Mapping (Just (chr 1099)) (LaTeX "y"),
  Mapping (Just (chr 1099)) (LaTeX "\\cyrery"),
  Mapping (Just (chr 1067)) (LaTeX "Y"),
  Mapping (Just (chr 1067)) (LaTeX "\\CYRERY"),
  Mapping (Just (chr 1100)) (LaTeX "\\cprime"),
  Mapping (Just (chr 1100)) (LaTeX "\\cyrsftsn"),
  Mapping (Just (chr 1068)) (LaTeX "\\Cprime"),
  Mapping (Just (chr 1068)) (LaTeX "\\CYRSFTSN"),
  Mapping (Just (chr 1101)) (LaTeX "\\`{e}"),
  Mapping (Just (chr 1101)) (LaTeX "\\cyrerev"),
  Mapping (Just (chr 1069)) (LaTeX "\\`{E}"),
  Mapping (Just (chr 1069)) (LaTeX "\\CYREREV"),
  Mapping (Just (chr 1102)) (LaTeX "yu"),
  Mapping (Just (chr 1102)) (LaTeX "\\cyryu"),
  Mapping (Just (chr 1070)) (LaTeX "Yu"),
  Mapping (Just (chr 1070)) (LaTeX "\\CYRYU"),
  Mapping (Just (chr 1103)) (LaTeX "ya"),
  Mapping (Just (chr 1103)) (LaTeX "\\cyrya"),
  Mapping (Just (chr 1071)) (LaTeX "Ya"),
  Mapping (Just (chr 1071)) (LaTeX "\\CYRYA"),
  Mapping (Just (chr 8470)) (LaTeX "N0"),
  Mapping (Just (chr 8470)) (LaTeX "\\textnumero"),
  Mapping (Just (chr 8470)) (LaTeX "\\textnumero"),
  Mapping (Just (chr 1106)) (LaTeX "dj"),
  Mapping (Just (chr 1106)) (LaTeX "\\cyrdje"),
  Mapping (Just (chr 1026)) (LaTeX "Dj"),
  Mapping (Just (chr 1026)) (LaTeX "\\CYRDJE"),
  Mapping (Just (chr 1107)) (LaTeX "\\'g"),
  Mapping (Just (chr 1107)) (LaTeX "\\cyrgup"),
  Mapping (Just (chr 1027)) (LaTeX "\\'G"),
  Mapping (Just (chr 1027)) (LaTeX "\\CYRGUP"),
  Mapping (Just (chr 1108)) (LaTeX "\\=e"),
  Mapping (Just (chr 1108)) (LaTeX "\\cyrie"),
  Mapping (Just (chr 1028)) (LaTeX "\\=E"),
  Mapping (Just (chr 1028)) (LaTeX "\\CYRIE"),
  Mapping (Just (chr 1109)) (LaTeX "\\dz"),
  Mapping (Just (chr 1109)) (LaTeX "\\cyrdze"),
  Mapping (Just (chr 1029)) (LaTeX "\\Dz"),
  Mapping (Just (chr 1029)) (LaTeX "\\CYRDZE"),
  Mapping (Just (chr 1110)) (LaTeX "\\=\\i"),
  Mapping (Just (chr 1110)) (LaTeX "\\cyrii"),
  Mapping (Just (chr 1030)) (LaTeX "\\=I"),
  Mapping (Just (chr 1030)) (LaTeX "\\CYRII"),
  Mapping (Just (chr 1111)) (LaTeX "\\\"\\i"),
  Mapping (Just (chr 1111)) (LaTeX "\\cyryi"),
  Mapping (Just (chr 1031)) (LaTeX "\\\"I"),
  Mapping (Just (chr 1031)) (LaTeX "\\CYRYI"),
  Mapping (Just (chr 1112)) (LaTeX "j"),
  Mapping (Just (chr 1112)) (LaTeX "\\cyrje"),
  Mapping (Just (chr 1032)) (LaTeX "J"),
  Mapping (Just (chr 1032)) (LaTeX "\\CYRJE"),
  Mapping (Just (chr 1113)) (LaTeX "lj"),
  Mapping (Just (chr 1113)) (LaTeX "\\cyrlje"),
  Mapping (Just (chr 1033)) (LaTeX "Lj"),
  Mapping (Just (chr 1033)) (LaTeX "\\CYRLJE"),
  Mapping (Just (chr 1114)) (LaTeX "nj"),
  Mapping (Just (chr 1114)) (LaTeX "\\cyrnje"),
  Mapping (Just (chr 1034)) (LaTeX "Nj"),
  Mapping (Just (chr 1034)) (LaTeX "\\CYRNJE"),
  Mapping (Just (chr 1115)) (LaTeX "\\'c"),
  Mapping (Just (chr 1115)) (LaTeX "\\cyrtshe"),
  Mapping (Just (chr 1035)) (LaTeX "\\'C"),
  Mapping (Just (chr 1035)) (LaTeX "\\CYRTSHE"),
  Mapping (Just (chr 1116)) (LaTeX "\\'k"),
  Mapping (Just (chr 1116)) (LaTeX "\\cyrkbeak"),
  Mapping (Just (chr 1036)) (LaTeX "\\'K"),
  Mapping (Just (chr 1036)) (LaTeX "\\CYRKBEAK"),
  Mapping (Just (chr 1118)) (LaTeX "\\u{u}"),
  Mapping (Just (chr 1118)) (LaTeX "\\cyrushrt"),
  Mapping (Just (chr 1038)) (LaTeX "\\u{U}"),
  Mapping (Just (chr 1038)) (LaTeX "\\CYRUSHRT"),
  Mapping (Just (chr 1119)) (LaTeX "\\dzh"),
  Mapping (Just (chr 1119)) (LaTeX "\\cyrdzhe"),
  Mapping (Just (chr 1039)) (LaTeX "\\Dzh"),
  Mapping (Just (chr 1039)) (LaTeX "\\CYRDZHE"),
  Mapping (Just (chr 945)) (LaTeX "a"),
  Mapping (Just (chr 913)) (LaTeX "A"),
  Mapping (Just (chr 913)) (LaTeX "A"),
  Mapping (Just (chr 946)) (LaTeX "b"),
  Mapping (Just (chr 914)) (LaTeX "B"),
  Mapping (Just (chr 914)) (LaTeX "B"),
  Mapping (Just (chr 947)) (LaTeX "g"),
  Mapping (Just (chr 915)) (LaTeX "G"),
  Mapping (Just (chr 948)) (LaTeX "d"),
  Mapping (Just (chr 916)) (LaTeX "D"),
  Mapping (Just (chr 949)) (LaTeX "e"),
  Mapping (Just (chr 917)) (LaTeX "E"),
  Mapping (Just (chr 917)) (LaTeX "E"),
  Mapping (Just (chr 950)) (LaTeX "z"),
  Mapping (Just (chr 918)) (LaTeX "Z"),
  Mapping (Just (chr 918)) (LaTeX "Z"),
  Mapping (Just (chr 951)) (LaTeX "h"),
  Mapping (Just (chr 919)) (LaTeX "H"),
  Mapping (Just (chr 919)) (LaTeX "H"),
  Mapping (Just (chr 952)) (LaTeX "j"),
  Mapping (Just (chr 920)) (LaTeX "J"),
  Mapping (Just (chr 953)) (LaTeX "i"),
  Mapping (Just (chr 921)) (LaTeX "I"),
  Mapping (Just (chr 921)) (LaTeX "I"),
  Mapping (Just (chr 954)) (LaTeX "k"),
  Mapping (Just (chr 922)) (LaTeX "K"),
  Mapping (Just (chr 922)) (LaTeX "K"),
  Mapping (Just (chr 955)) (LaTeX "l"),
  Mapping (Just (chr 923)) (LaTeX "L"),
  Mapping (Just (chr 956)) (LaTeX "m"),
  Mapping (Just (chr 924)) (LaTeX "M"),
  Mapping (Just (chr 924)) (LaTeX "M"),
  Mapping (Just (chr 957)) (LaTeX "n"),
  Mapping (Just (chr 925)) (LaTeX "N"),
  Mapping (Just (chr 925)) (LaTeX "N"),
  Mapping (Just (chr 958)) (LaTeX "x"),
  Mapping (Just (chr 926)) (LaTeX "X"),
  Mapping (Just (chr 959)) (LaTeX "o"),
  Mapping (Just (chr 959)) (LaTeX "o"),
  Mapping (Just (chr 927)) (LaTeX "O"),
  Mapping (Just (chr 927)) (LaTeX "O"),
  Mapping (Just (chr 960)) (LaTeX "p"),
  Mapping (Just (chr 928)) (LaTeX "P"),
  Mapping (Just (chr 961)) (LaTeX "r"),
  Mapping (Just (chr 929)) (LaTeX "P"),
  Mapping (Just (chr 929)) (LaTeX "R"),
  Mapping (Just (chr 963)) (LaTeX "s"),
  Mapping (Just (chr 931)) (LaTeX "S"),
  Mapping (Just (chr 962)) (LaTeX "c"),
  Mapping (Just (chr 964)) (LaTeX "t"),
  Mapping (Just (chr 932)) (LaTeX "T"),
  Mapping (Just (chr 932)) (LaTeX "T"),
  Mapping (Just (chr 965)) (LaTeX "u"),
  Mapping (Just (chr 933)) (LaTeX "Y"),
  Mapping (Just (chr 933)) (LaTeX "U"),
  Mapping (Just (chr 966)) (LaTeX "f"),
  Mapping (Just (chr 934)) (LaTeX "F"),
  Mapping (Just (chr 967)) (LaTeX "q"),
  Mapping (Just (chr 935)) (LaTeX "X"),
  Mapping (Just (chr 935)) (LaTeX "Q"),
  Mapping (Just (chr 968)) (LaTeX "y"),
  Mapping (Just (chr 936)) (LaTeX "Y"),
  Mapping (Just (chr 969)) (LaTeX "w"),
  Mapping (Just (chr 937)) (LaTeX "W"),
  Mapping (Just (chr 940)) (LaTeX "'a"),
  Mapping (Just (chr 902)) (LaTeX "'A"),
  Mapping (Just (chr 941)) (LaTeX "'e"),
  Mapping (Just (chr 904)) (LaTeX "'E"),
  Mapping (Just (chr 942)) (LaTeX "'h"),
  Mapping (Just (chr 905)) (LaTeX "'H"),
  Mapping (Just (chr 970)) (LaTeX "\"i"),
  Mapping (Just (chr 938)) (LaTeX "\"I"),
  Mapping (Just (chr 943)) (LaTeX "'i"),
  Mapping (Just (chr 906)) (LaTeX "'I"),
  Mapping (Just (chr 912)) (LaTeX "\"'i"),
  Mapping (Just (chr 972)) (LaTeX "'o"),
  Mapping (Just (chr 908)) (LaTeX "'O"),
  Mapping (Just (chr 971)) (LaTeX "\"u"),
  Mapping (Just (chr 939)) (LaTeX "\"U"),
  Mapping (Just (chr 973)) (LaTeX "'u"),
  Mapping (Just (chr 910)) (LaTeX "'U"),
  Mapping (Just (chr 944)) (LaTeX "\"'u"),
  Mapping (Just (chr 974)) (LaTeX "'w"),
  Mapping (Just (chr 911)) (LaTeX "'W"),
  Mapping (Just (chr 9)) (LaTeX "\\>,\\="),
  Mapping (Just (chr 10)) (LaTeX "\\\\"),
  Mapping (Just (chr 8249)) (LaTeX "\\guilsinglleft"),
  Mapping (Just (chr 8250)) (LaTeX "\\guilsinglright"),
  Mapping (Just (chr 8254)) (LaTeX "\\={}"),
  Mapping (Just (chr 8260)) (LaTeX "\\textfractionsolidus"),
  Mapping (Just (chr 8364)) (LaTeX "\\texteuro"),
  Mapping Nothing (LaTeXMath "\\leftrightarrowtriangle"),
  Mapping (Just (chr 8672)) (LaTeXMath "\\dashleftarrow"),
  Mapping Nothing (LaTeXMath "\\leftarrowtriangle"),
  Mapping (Just (chr 8674)) (LaTeXMath "\\dashrightarrow"),
  Mapping (Just (chr 8674)) (LaTeXMath "\\dasharrow"),
  Mapping Nothing (LaTeXMath "\\rightarrowtriangle"),
  Mapping Nothing (LaTeXMath "\\shortleftarrow"),
  Mapping Nothing (LaTeXMath "\\shortrightarrow"),
  Mapping Nothing (LaTeXMath "\\longleftarrow"),
  Mapping Nothing (LaTeXMath "\\longmapsto"),
  Mapping Nothing (LaTeXMath "\\longrightarrow"),
  Mapping Nothing (LaTeXMath "\\boxbslash"),
  Mapping Nothing (LaTeXMath "\\ogreaterthan"),
  Mapping Nothing (LaTeXMath "\\minuso"),
  Mapping Nothing (LaTeXMath "\\varocircle"),
  Mapping Nothing (LaTeXMath "\\olessthan"),
  Mapping Nothing (LaTeXMath "\\obar"),
  Mapping Nothing (LaTeXMath "\\boxslash"),
  Mapping Nothing (LaTeXMath "\\bigcap"),
  Mapping Nothing (LaTeXMath "\\bigcup"),
  Mapping Nothing (LaTeXMath "\\bigodot"),
  Mapping Nothing (LaTeXMath "\\bigoplus"),
  Mapping Nothing (LaTeXMath "\\bigotimes"),
  Mapping Nothing (LaTeXMath "\\bigsqcup"),
  Mapping Nothing (LaTeXMath "\\biguplus"),
  Mapping Nothing (LaTeXMath "\\bigvee"),
  Mapping Nothing (LaTeXMath "\\bigwedge"),
  Mapping Nothing (LaTeXMath "\\lmoustache"),
  Mapping Nothing (LaTeXMath "\\rlap{$&lt;$}\\;("),
  Mapping Nothing (LaTeXMath "\\rmoustache"),
  Mapping Nothing (LaTeXMath "\\varnothing"),
  Mapping (Just (chr 8487)) (LaTeX "\\textmho"),
  Mapping (Just (chr 8487)) (LaTeXMath "\\mho"),
  Mapping Nothing (LaTeXMath "\\hslash"),
  Mapping (Just (chr 8759)) (LaTeXMath "::"),
  Mapping Nothing (LaTeXMath "::="),
  Mapping Nothing (LaTeXMath "&gt;&lt;"),
  Mapping Nothing (LaTeXMath "\\rlap{$>$}\\!&lt;"),
  Mapping Nothing (LaTeXMath "\\rightslice"),
  Mapping Nothing (LaTeXMath "\\leftslice"),
  Mapping Nothing (LaTeXMath "a"),
  Mapping Nothing (LaTeXMath "A"),
  Mapping Nothing (LaTeXMath "b"),
  Mapping Nothing (LaTeXMath "B"),
  Mapping Nothing (LaTeXMath "c"),
  Mapping Nothing (LaTeXMath "C"),
  Mapping Nothing (LaTeXMath "d"),
  Mapping Nothing (LaTeXMath "D"),
  Mapping Nothing (LaTeXMath "e"),
  Mapping Nothing (LaTeXMath "E"),
  Mapping Nothing (LaTeXMath "f"),
  Mapping Nothing (LaTeXMath "F"),
  Mapping Nothing (LaTeXMath "g"),
  Mapping Nothing (LaTeXMath "G"),
  Mapping Nothing (LaTeXMath "h"),
  Mapping Nothing (LaTeXMath "H"),
  Mapping Nothing (LaTeXMath "i"),
  Mapping Nothing (LaTeXMath "I"),
  Mapping Nothing (LaTeXMath "j"),
  Mapping Nothing (LaTeXMath "J"),
  Mapping Nothing (LaTeXMath "k"),
  Mapping Nothing (LaTeXMath "K"),
  Mapping Nothing (LaTeXMath "l"),
  Mapping Nothing (LaTeXMath "L"),
  Mapping Nothing (LaTeXMath "m"),
  Mapping Nothing (LaTeXMath "M"),
  Mapping Nothing (LaTeXMath "n"),
  Mapping Nothing (LaTeXMath "N"),
  Mapping Nothing (LaTeXMath "o"),
  Mapping Nothing (LaTeXMath "O"),
  Mapping Nothing (LaTeXMath "p"),
  Mapping Nothing (LaTeXMath "P"),
  Mapping Nothing (LaTeXMath "q"),
  Mapping Nothing (LaTeXMath "Q"),
  Mapping Nothing (LaTeXMath "r"),
  Mapping Nothing (LaTeXMath "R"),
  Mapping Nothing (LaTeXMath "s"),
  Mapping Nothing (LaTeXMath "S"),
  Mapping Nothing (LaTeXMath "t"),
  Mapping Nothing (LaTeXMath "T"),
  Mapping Nothing (LaTeXMath "u"),
  Mapping Nothing (LaTeXMath "U"),
  Mapping Nothing (LaTeXMath "v"),
  Mapping Nothing (LaTeXMath "V"),
  Mapping Nothing (LaTeXMath "w"),
  Mapping Nothing (LaTeXMath "W"),
  Mapping Nothing (LaTeXMath "x"),
  Mapping Nothing (LaTeXMath "X"),
  Mapping Nothing (LaTeXMath "y"),
  Mapping Nothing (LaTeXMath "Y"),
  Mapping Nothing (LaTeXMath "z"),
  Mapping Nothing (LaTeXMath "Z"),
  Mapping Nothing (LaTeXMath "A"),
  Mapping Nothing (LaTeXMath "B"),
  Mapping Nothing (LaTeXMath "C"),
  Mapping Nothing (LaTeXMath "D"),
  Mapping Nothing (LaTeXMath "E"),
  Mapping Nothing (LaTeXMath "F"),
  Mapping Nothing (LaTeXMath "G"),
  Mapping Nothing (LaTeXMath "H"),
  Mapping Nothing (LaTeXMath "I"),
  Mapping Nothing (LaTeXMath "J"),
  Mapping Nothing (LaTeXMath "K"),
  Mapping Nothing (LaTeXMath "L"),
  Mapping Nothing (LaTeXMath "M"),
  Mapping Nothing (LaTeXMath "N"),
  Mapping Nothing (LaTeXMath "O"),
  Mapping Nothing (LaTeXMath "P"),
  Mapping Nothing (LaTeXMath "Q"),
  Mapping Nothing (LaTeXMath "R"),
  Mapping Nothing (LaTeXMath "S"),
  Mapping Nothing (LaTeXMath "T"),
  Mapping Nothing (LaTeXMath "U"),
  Mapping Nothing (LaTeXMath "V"),
  Mapping Nothing (LaTeXMath "W"),
  Mapping Nothing (LaTeXMath "X"),
  Mapping Nothing (LaTeXMath "Y"),
  Mapping Nothing (LaTeXMath "Z"),
  Mapping Nothing (LaTeXMath "A"),
  Mapping Nothing (LaTeXMath "B"),
  Mapping Nothing (LaTeXMath "C"),
  Mapping Nothing (LaTeXMath "D"),
  Mapping Nothing (LaTeXMath "E"),
  Mapping Nothing (LaTeXMath "F"),
  Mapping Nothing (LaTeXMath "G"),
  Mapping Nothing (LaTeXMath "H"),
  Mapping Nothing (LaTeXMath "I"),
  Mapping Nothing (LaTeXMath "J"),
  Mapping Nothing (LaTeXMath "K"),
  Mapping Nothing (LaTeXMath "L"),
  Mapping Nothing (LaTeXMath "M"),
  Mapping Nothing (LaTeXMath "N"),
  Mapping Nothing (LaTeXMath "O"),
  Mapping Nothing (LaTeXMath "P"),
  Mapping Nothing (LaTeXMath "Q"),
  Mapping Nothing (LaTeXMath "R"),
  Mapping Nothing (LaTeXMath "S"),
  Mapping Nothing (LaTeXMath "T"),
  Mapping Nothing (LaTeXMath "U"),
  Mapping Nothing (LaTeXMath "V"),
  Mapping Nothing (LaTeXMath "W"),
  Mapping Nothing (LaTeXMath "X"),
  Mapping Nothing (LaTeXMath "Y"),
  Mapping Nothing (LaTeXMath "Z"),
  Mapping Nothing (LaTeXMath "\\AC"),
  Mapping Nothing (LaTeXMath "\\merge"),
  Mapping Nothing (LaTeXMath "\\cdots"),
  Mapping Nothing (LaTeXMath "\\ddots"),
  Mapping Nothing (LaTeXMath "\\int\\!\\!\\!\\int"),
  Mapping Nothing (LaTeXMath "\\inplus"),
  Mapping (Just (chr 12314)) (LaTeX "\\textlbrackdbl"),
  Mapping (Just (chr 12314)) (LaTeXMath "\\llbracket"),
  Mapping Nothing (LaTeXMath "\\niplus"),
  Mapping (Just (chr 8241)) (LaTeX "\\textpertenthousand"),
  Mapping Nothing (LaTeXMath "\\int\\!\\!\\!\\int\\!\\!\\!\\int\\!\\!\\!\\int"),
  Mapping (Just (chr 12315)) (LaTeX "\\textrbrackdbl"),
  Mapping (Just (chr 12315)) (LaTeXMath "\\rrbracket"),
  Mapping Nothing (LaTeXMath "\\rrparenthesis"),
  Mapping Nothing (LaTeXMath "\\int\\!\\!\\!\\int\\!\\!\\!\\int"),
  Mapping (Just (chr 717)) (LaTeX "\\b{}"),
  Mapping (Just (chr 803)) (LaTeX "\\d{}"),
  Mapping (Just (chr 865)) (LaTeX "\\t{}"),
  Mapping (Just (chr 8251)) (LaTeX "\\textreferencemark"),
  Mapping Nothing (LaTeXMath "\\!")
  ]
